<?php

if (!function_exists('urna_tbay_private_size_image_setup')) {
    /**
     * Setup custom image sizes for the theme.
     *
     * @since Urna 1.0
     */
    function urna_tbay_private_size_image_setup() {
        set_post_thumbnail_size(390, 251, true); // Width: 390px, Height: 251px, Hard crop

        if (!urna_tbay_get_global_config('config_media', false)) {
            $image_sizes = [
                'thumbnail' => ['width' => 585, 'height' => 377],
                'medium'    => ['width' => 570, 'height' => 330],
                'large'     => ['width' => 770, 'height' => 440],
            ];

            foreach ($image_sizes as $size => $dimensions) {
                update_option("{$size}_size_w", absint($dimensions['width']));
                update_option("{$size}_size_h", absint($dimensions['height']));
            }
        }
    }
    add_action('after_setup_theme', 'urna_tbay_private_size_image_setup');
}

if (!function_exists('urna_tbay_private_menu_setup')) {
    /**
     * Register navigation menus for the theme.
     *
     * @since Urna 1.0
     */
    function urna_tbay_private_menu_setup() {
        register_nav_menus([
            'primary'           => esc_html__('Primary Menu', 'urna'),
            'mobile-menu'       => esc_html__('Mobile Menu', 'urna'),
            'nav-category-menu' => esc_html__('Nav Category Menu', 'urna'),
            'track-order'       => esc_html__('Tracking Order Menu', 'urna'),
            'flash-sale'        => esc_html__('Flash Sale Menu', 'urna'),
        ]);
    }
    add_action('after_setup_theme', 'urna_tbay_private_menu_setup');
}

if (!function_exists('urna_fonts_url')) {
    /**
     * Generate Google Fonts URL for the theme with transient caching.
     *
     * @since Urna 1.0
     * @return string Google Fonts URL or empty string if fonts are disabled.
     */
    function urna_fonts_url() {
        $transient_key = 'urna_fonts_url';
        $fonts_url = get_transient($transient_key);

        if (!$fonts_url) { // Chỉ tính toán nếu transient không tồn tại hoặc hết hạn
            $poppins_enabled = _x('on', 'Poppins font: on or off', 'urna');

            if ('off' !== $poppins_enabled) {
                $font_families = ['Poppins:400,500,600,700'];
                
                $query_args = [
                    'family'  => rawurlencode(implode('|', $font_families)),
                    'subset'  => urlencode('latin,latin-ext'),
                    'display' => urlencode('swap'),
                ];

                $protocol = is_ssl() ? 'https' : 'http';
                $fonts_url = add_query_arg($query_args, "$protocol://fonts.googleapis.com/css");
            } else {
                $fonts_url = ''; // Đảm bảo giá trị mặc định là chuỗi rỗng
            }

            // Lưu vào transient với thời gian hết hạn 1 tuần
            set_transient($transient_key, $fonts_url, WEEK_IN_SECONDS);
        }

        return esc_url_raw($fonts_url);
    }
}

if (!function_exists('urna_tbay_fonts_url')) {
    /**
     * Enqueue theme fonts based on configuration.
     *
     * @since Urna 1.0
     */
    function urna_tbay_fonts_url() {
        $show_typography = urna_tbay_get_config('show_typography', false);
        $font_source = urna_tbay_get_config('font_source', '1');
        $font_google_code = urna_tbay_get_config('font_google_code');

        if (!$show_typography) {
            wp_enqueue_style('urna-theme-fonts', urna_fonts_url(), [], null);
        } elseif ('2' === $font_source && !empty($font_google_code)) {
            wp_enqueue_style('urna-theme-fonts', esc_url_raw($font_google_code), [], null);
        }
    }
    add_action('wp_enqueue_scripts', 'urna_tbay_fonts_url');
}

if (!function_exists('urna_marketplace_v1_category_inside_class_open')) {
    /**
     * Determine the class for category inside based on homepage status.
     *
     * @since Urna 1.0
     * @return string 'open' if on homepage, empty string otherwise.
     */
    function urna_marketplace_v1_category_inside_class_open() {
        return urna_tbay_is_home_page() ? 'open' : '';
    }
    add_filter('urna_category_inside_class', 'urna_marketplace_v1_category_inside_class_open');
}