<?php

if (!defined('URNA_THEME_DIR')) {
    exit('No direct script access allowed');
}

if (!function_exists('urna_tbay_private_size_image_setup')) {
    /**
     * Setup custom image sizes for the theme.
     *
     * @since Urna 1.0
     */
    function urna_tbay_private_size_image_setup() {
        set_post_thumbnail_size(555, 360, true); // Width: 555px, Height: 360px, Hard crop

        if (!urna_tbay_get_global_config('config_media', false)) {
            $image_sizes = [
                'thumbnail' => ['width' => 555, 'height' => 360],
                'medium'    => ['width' => 570, 'height' => 330],
                'large'     => ['width' => 770, 'height' => 440],
            ];

            foreach ($image_sizes as $size => $dimensions) {
                update_option("{$size}_size_w", absint($dimensions['width']));
                update_option("{$size}_size_h", absint($dimensions['height']));
            }
        }
    }
    add_action('after_setup_theme', 'urna_tbay_private_size_image_setup');
}

if (!function_exists('urna_tbay_private_menu_setup')) {
    /**
     * Register navigation menus for the theme.
     *
     * @since Urna 1.0
     */
    function urna_tbay_private_menu_setup() {
        register_nav_menus([
            'primary'           => esc_html__('Primary Menu', 'urna'),
            'mobile-menu'       => esc_html__('Mobile Menu', 'urna'),
            'nav-category-menu' => esc_html__('Nav Category Menu', 'urna'),
            'track-order'       => esc_html__('Tracking Order Menu', 'urna'),
        ]);
    }
    add_action('after_setup_theme', 'urna_tbay_private_menu_setup');
}

if (!function_exists('urna_fonts_url')) {
    /**
     * Generate Google Fonts URL for the theme with transient caching.
     *
     * @since Urna 1.0
     * @return string Google Fonts URL or empty string if fonts are disabled.
     */
    function urna_fonts_url() {
        $transient_key = 'urna_fonts_url';
        $fonts_url = get_transient($transient_key);

        if (!$fonts_url) {
            $poppins_enabled = _x('on', 'Poppins font: on or off', 'urna');

            if ('off' !== $poppins_enabled) {
                $font_families = ['Poppins:400,500,600'];
                $query_args = [
                    'family'  => rawurlencode(implode('|', $font_families)),
                    'subset'  => urlencode('latin,latin-ext'),
                    'display' => urlencode('swap'),
                ];
                $protocol = is_ssl() ? 'https' : 'http';
                $fonts_url = add_query_arg($query_args, "$protocol://fonts.googleapis.com/css");
            } else {
                $fonts_url = '';
            }

            set_transient($transient_key, $fonts_url, WEEK_IN_SECONDS);
        }

        return esc_url_raw($fonts_url);
    }
}

if (!function_exists('urna_tbay_fonts_url')) {
    /**
     * Enqueue theme fonts based on configuration.
     *
     * @since Urna 1.0
     */
    function urna_tbay_fonts_url() {
        $show_typography = urna_tbay_get_config('show_typography', false);
        $font_source = urna_tbay_get_config('font_source', '1');
        $font_google_code = urna_tbay_get_config('font_google_code');

        if (!$show_typography) {
            wp_enqueue_style('urna-theme-fonts', urna_fonts_url(), [], null);
        } elseif ('2' === $font_source && !empty($font_google_code)) {
            wp_enqueue_style('urna-theme-fonts', esc_url_raw($font_google_code), [], null);
        }
    }
    add_action('wp_enqueue_scripts', 'urna_tbay_fonts_url');
}

if (!function_exists('urna_tbay_private_widgets_init')) {
    /**
     * Register widget areas for the theme.
     *
     * @since Urna 1.0
     */
    function urna_tbay_private_widgets_init() {
        if (defined('URNA_CORE_ACTIVED') && URNA_CORE_ACTIVED) {
            register_sidebar([
                'name'          => esc_html__('Canvas Menu Sidebar', 'urna'),
                'id'            => 'canvas-menu',
                'description'   => esc_html__('Add widgets here to appear in canvas menu sidebar.', 'urna'),
                'before_widget' => '<aside id="%1$s" class="widget %2$s">',
                'after_widget'  => '</aside>',
                'before_title'  => '<h2 class="widget-title">',
                'after_title'   => '</h2>',
            ]);
        }
    }
    add_action('widgets_init', 'urna_tbay_private_widgets_init');
}