<?php

if (!defined('URNA_THEME_DIR')) {
    exit('No direct script access allowed');
}

if (!function_exists('urna_tbay_private_size_image_setup')) {
    /**
     * Setup custom image sizes for the theme.
     *
     * @since Urna 1.0
     */
    function urna_tbay_private_size_image_setup() {
        set_post_thumbnail_size(310, 180, true); // Width: 310px, Height: 180px, Hard crop

        if (!urna_tbay_get_global_config('config_media', false)) {
            $image_sizes = [
                'thumbnail' => ['width' => 310, 'height' => 180], // Đồng bộ với set_post_thumbnail_size
                'medium'    => ['width' => 570, 'height' => 330],
                'large'     => ['width' => 770, 'height' => 440],
            ];

            foreach ($image_sizes as $size => $dimensions) {
                update_option("{$size}_size_w", absint($dimensions['width']));
                update_option("{$size}_size_h", absint($dimensions['height']));
            }
        }
    }
    add_action('after_setup_theme', 'urna_tbay_private_size_image_setup');
}

if (!function_exists('urna_tbay_private_menu_setup')) {
    /**
     * Register navigation menus for the theme.
     *
     * @since Urna 1.0
     */
    function urna_tbay_private_menu_setup() {
        register_nav_menus([
            'primary'           => esc_html__('Primary Menu', 'urna'),
            'mobile-menu'       => esc_html__('Mobile Menu', 'urna'),
            'nav-category-menu' => esc_html__('Nav Category Menu', 'urna'),
            'track-order'       => esc_html__('Tracking Order Menu', 'urna'),
        ]);
    }
    add_action('after_setup_theme', 'urna_tbay_private_menu_setup');
}

if (!function_exists('urna_fonts_url')) {
    /**
     * Generate Google Fonts URL for the theme with transient caching.
     *
     * @since Urna 1.0
     * @return string Google Fonts URL or empty string if fonts are disabled.
     */
    function urna_fonts_url() {
        $transient_key = 'urna_fonts_url';
        $fonts_url = get_transient($transient_key);

        if (!$fonts_url) {
            $poppins_enabled = _x('on', 'Poppins font: on or off', 'urna');
            $fredoka_enabled = _x('on', 'Fredoka One font: on or off', 'urna');

            if ('off' !== $poppins_enabled || 'off' !== $fredoka_enabled) {
                $font_families = [];

                if ('off' !== $poppins_enabled) {
                    $font_families[] = 'Poppins:400,500,600,700';
                }
                if ('off' !== $fredoka_enabled) {
                    $font_families[] = 'Fredoka One:400';
                }

                $query_args = [
                    'family'  => rawurlencode(implode('|', $font_families)),
                    'subset'  => urlencode('latin,latin-ext'),
                    'display' => urlencode('swap'),
                ];
                $protocol = is_ssl() ? 'https' : 'http';
                $fonts_url = add_query_arg($query_args, "$protocol://fonts.googleapis.com/css");
            } else {
                $fonts_url = '';
            }

            set_transient($transient_key, $fonts_url, WEEK_IN_SECONDS);
        }

        return esc_url_raw($fonts_url);
    }
}

if (!function_exists('urna_tbay_fonts_url')) {
    /**
     * Enqueue theme fonts based on configuration.
     *
     * @since Urna 1.0
     */
    function urna_tbay_fonts_url() {
        $show_typography = urna_tbay_get_config('show_typography', false);
        $font_source = urna_tbay_get_config('font_source', '1');
        $font_google_code = urna_tbay_get_config('font_google_code');

        if (!$show_typography) {
            wp_enqueue_style('urna-theme-fonts', urna_fonts_url(), [], null);
        } elseif ('2' === $font_source && !empty($font_google_code)) {
            wp_enqueue_style('urna-theme-fonts', esc_url_raw($font_google_code), [], null);
        }
    }
    add_action('wp_enqueue_scripts', 'urna_tbay_fonts_url');
}

if (!function_exists('urna_tbay_skin_add_text')) {
    /**
     * Customize the compare text for the theme skin.
     *
     * @since Urna 1.0
     * @return string The translated 'Compare' text.
     */
    function urna_tbay_skin_add_text() {
        return esc_html__('Compare', 'urna');
    }
    add_filter('urna_get_text_compare', 'urna_tbay_skin_add_text', 2);
}