<?php if (! defined('URNA_THEME_DIR')) {
    exit('No direct script access allowed');
}

/**
 * Display navigation to next/previous comments when applicable.
 *
 * @since Urna 1.0
 */
if (!function_exists('urna_tbay_comment_nav')) {
    function urna_tbay_comment_nav() {
        if (get_comment_pages_count() <= 1 || !get_option('page_comments')) {
            return;
        }

        $prev_link = get_previous_comments_link(esc_html__('Older Comments', 'urna'));
        $next_link = get_next_comments_link(esc_html__('Newer Comments', 'urna'));

        if ($prev_link || $next_link) {
            ?>
            <nav class="navigation comment-navigation">
                <h2 class="screen-reader-text"><?php esc_html_e('Comment navigation', 'urna'); ?></h2>
                <div class="nav-links">
                    <?php if ($prev_link) : ?>
                        <div class="nav-previous"><?php echo $prev_link; ?></div>
                    <?php endif; ?>
                    <?php if ($next_link) : ?>
                        <div class="nav-next"><?php echo $next_link; ?></div>
                    <?php endif; ?>
                </div>
            </nav>
            <?php
        }
    }
}

/**
 * Prints HTML with meta information for the categories, tags.
 *
 * @since Urna 1.0
 */
if (!function_exists('urna_tbay_entry_meta')) {
    function urna_tbay_entry_meta() {
        $output = '';

        // Sticky post
        if (is_sticky() && is_home() && !is_paged()) {
            $output .= sprintf('<span class="sticky-post">%s</span>', esc_html__('Featured', 'urna'));
        }

        // Post format
        $format = get_post_format();
        if (current_theme_supports('post-formats', $format)) {
            $output .= sprintf(
                '<span class="entry-format">%s<a href="%s">%s</a></span>',
                sprintf('<span class="screen-reader-text">%s </span>', esc_html_x('Format', 'Used before post format.', 'urna')),
                esc_url(get_post_format_link($format)),
                esc_html(get_post_format_string($format))
            );
        }

        // Post date
        if (in_array(get_post_type(), ['post', 'attachment'])) {
            $time_string = urna_tbay_get_time_string();
            $output .= sprintf(
                '<span class="posted-on"><span class="screen-reader-text">%s </span><a href="%s" rel="bookmark">%s</a></span>',
                esc_html_x('Posted on', 'Used before publish date.', 'urna'),
                esc_url(get_permalink()),
                $time_string
            );
        }

        // Xuất HTML
        echo $output;
    }
}

/**
 * Get formatted time string for post date.
 *
 * @return string Formatted time HTML.
 */
if (!function_exists('urna_tbay_get_time_string')) {
    function urna_tbay_get_time_string() {
        $time_string = '<time class="published updated" datetime="%1$s">%2$s</time>';
        if (get_the_time('U') !== get_the_modified_time('U')) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
        }
        return sprintf(
            $time_string,
            esc_attr(get_the_date('c')),
            get_the_date(),
            esc_attr(get_the_modified_date('c')),
            get_the_modified_date()
        );
    }
}

/**
 * Display post thumbnail.
 *
 * @since Urna 1.0
 */
if (!function_exists('urna_tbay_post_thumbnail')) {
    function urna_tbay_post_thumbnail() {
        if (post_password_required() || is_attachment() || !has_post_thumbnail()) {
            return;
        }

        if (is_singular()) {
            echo '<div class="post-thumbnail">';
            the_post_thumbnail('full');
            echo '</div>';
        } else {
            $image_size = apply_filters('urna_archive_blog_size_image', 'medium');
            printf(
                '<a class="post-%s" href="%s" aria-hidden="true">%s</a>',
                esc_attr($image_size),
                esc_url(get_permalink()),
                get_the_post_thumbnail(null, $image_size, ['alt' => esc_attr(get_the_title())])
            );
        }
    }
}

if (! function_exists('urna_tbay_post_categories')) {
    function urna_tbay_post_categories($post)
    {
        $cat = wp_get_post_categories($post->ID);
        $k   = count($cat);
        foreach ($cat as $c) {
            $categories = get_category($c);
            $k -= 1;
            if ($k == 0) {
                echo '<a href="' . get_category_link($categories->term_id) . '" class="categories-name">' . esc_html($categories->name) . '</a>';
            } else {
                echo '<a href="' . get_category_link($categories->term_id) . '" class="categories-name">' . esc_html($categories->name) . ', </a>';
            }
        }
    }
}

if (! function_exists('urna_tbay_short_top_meta')) {
    function urna_tbay_short_top_meta($post)
    {
        ?>
        <div class="entry-create">
            <span class="entry-date"><?php echo urna_time_link(); ?></span>
            <span class="author"><?php esc_html_e('/ By ', 'urna');
        the_author_posts_link(); ?></span>
        </div>
		<?php
    }
}

if (! function_exists('urna_tbay_get_link_url')) :
/**
 * Return the post URL.
 *
 * Falls back to the post permalink if no URL is found in the post.
 *
 * @since Urna 1.0
 *
 * @see get_url_in_content()
 *
 * @return string The Link format URL.
 */
function urna_tbay_get_link_url()
{
    $has_url = get_url_in_content(get_the_content());

    return $has_url ? $has_url : apply_filters('the_permalink', get_permalink());
}
endif;

if (! function_exists('urna_tbay_excerpt_more') && ! is_admin()) :
/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and a 'Continue reading' link.
 *
 * @since Urna 1.0
 *
 * @return string 'Continue reading' link prepended with an ellipsis.
 */
function urna_tbay_excerpt_more($more)
{
    $link = sprintf(
        '<a href="%1$s" class="more-link">%2$s</a>',
        esc_url(get_permalink(get_the_ID())),
        /* translators: %s: Name of current post */
        sprintf(esc_html__('Continue reading %s', 'urna'), '<span class="screen-reader-text">' . get_the_title(get_the_ID()) . '</span>')
    );
    return ' &hellip; ' . $link;
}
add_filter('excerpt_more', 'urna_tbay_excerpt_more');
endif;

if (! function_exists('urna_tbay_icon_post_formats')) {
    function urna_tbay_icon_post_formats()
    {
        $post_id 			= get_the_ID();
        $post_format 	= get_post_format($post_id);

        switch ($post_format) {
                case 'aside':
                    echo '<i class="linear-icon-document"></i>';
                    break;
                case 'audio':
                    echo '<i class="linear-icon-music-note2"></i>';
                    break;
                case 'gallery':
                    echo '<i class="linear-icon-pictures"></i>';
                    break;
                case 'image':
                    echo '<i class="linear-icon-picture2"></i>';
                    break;
                case 'link':
                    echo '<i class="linear-icon-link2"></i>';
                    break;
                case 'quote':
                    echo '<i class="linear-quote-open"></i>';
                    break;
                case 'video':
                    echo '<i class="linear-icon-clapboard-play"></i>';
                    break;
                
                default:
                    echo '<i class="linear-icon-pushpin"></i>';
                    break;
            }
    }
}

/**
 * ------------------------------------------------------------------------------------------------
 * Display meta information for a specific post
 * ------------------------------------------------------------------------------------------------
 */
if (! function_exists('urna_post_meta')) {
    function urna_post_meta($atts = array())
    {
        extract(shortcode_atts(array(
            'date'     => 1,
            'author'   => 1,
            'comments' => 1,
            'tags'     => 0,
            'cats'     => 0,
            'edit'     => 1,
        ), $atts)); ?>
		<?php if (get_post_type() === 'post'): ?>
			<ul class="entry-meta-list">

				<?php // Date?>
				<?php if ($date == 1): ?>
					<li class="entry-date"><i class="linear-icon-calendar-31"></i><?php echo urna_time_link(); ?></li>
				<?php endif ?>

				<?php // Author?>
				<?php if ($author == 1): ?>
					<li class="entry-author"><?php echo get_avatar(urna_tbay_get_id_author_post(), 70); ?> <?php the_author_posts_link(); ?></li>
				<?php endif ?>


				<?php // Comments?>
				<?php if ($comments && comments_open()): ?>
					<li class="comments-link"><i class="linear-icon-bubbles"></i><?php comments_popup_link('0', '1', '%'); ?></li>
				<?php endif; ?>


				<?php // Tags?>
				<?php if (get_the_tag_list('', ', ') && $tags == 1): ?>
					<li class="entry-tags"><?php echo get_the_tag_list('', ', '); ?></li>
				<?php endif; ?>

				<?php // Categories?>
				<?php if (get_the_category_list(', ') && $cats == 1): ?>
					<li class="entry-category"><i class="linear-icon-tag"></i><span><?php esc_html_e('Categories: ', 'urna'); ?></span><?php urna_the_post_category_full() ?></li>
				<?php endif; ?>

				<?php // Edit link?>
				<?php if (is_user_logged_in() && $edit == 1): ?>
					<li class="edit-link"><?php edit_post_link(esc_html__('Edit', 'urna')); ?></li>
				<?php endif; ?>
			</ul>
			<?php endif; ?>
		<?php
    }
}

/**
 * ------------------------------------------------------------------------------------------------
 * The archive title
 * ------------------------------------------------------------------------------------------------
 */
if (! function_exists('urna_post_archive_the_title')) {
    function urna_post_archive_the_title()
    {
        if (get_the_title()) {
            ?>
	        <h3 class="entry-title">
	           <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
	        </h3>
	    <?php
        }
    }
}

/**
 * ------------------------------------------------------------------------------------------------
 * The short description archive
 * ------------------------------------------------------------------------------------------------
 */
if (! function_exists('urna_post_archive_the_short_description')) {
    function urna_post_archive_the_short_description()
    {
        if (empty(get_the_excerpt()) || get_the_excerpt() == '&nbsp;') {
            return;
        }
        if (has_excerpt()) { ?>
			<div class="entry-description">
				<?php echo urna_tbay_substring(get_the_excerpt(), 30, '[...]'); ?>
			</div>
		<?php } else {
            ?>
				<div class="entry-description">
					<?php echo urna_tbay_substring(get_the_content(), 25, '...'); ?>
				</div>
			<?php
        }
    }
}
/**
 * ------------------------------------------------------------------------------------------------
 * The read more archive
 * ------------------------------------------------------------------------------------------------
 */
if (! function_exists('urna_post_archive_the_read_more')) {
    function urna_post_archive_the_read_more()
    {
        ?>
			<?php $custom_readmore	= urna_tbay_get_config('text_readmore', esc_html__('Continue Reading', 'urna')); ?>
			<div class="more">
				<a href="<?php the_permalink(); ?>" class="readmore" title="<?php echo trim($custom_readmore); ?>"><i class="linear-icon-plus"></i><?php echo trim($custom_readmore); ?></a>
			</div>
		<?php
    }
}

/**
 * Extend search to include SKU.
 *
 * @param string $search Original search query.
 * @return string Modified search query.
 */
function urna_search_sku($search) {
    global $pagenow, $wpdb, $wp;

    if ((is_admin() && 'edit.php' !== $pagenow) || 
        !is_search() || 
        !isset($wp->query_vars['s']) || 
        (isset($wp->query_vars['post_type']) && 'product' !== $wp->query_vars['post_type']) || 
        (isset($wp->query_vars['post_type']) && is_array($wp->query_vars['post_type']) && !in_array('product', $wp->query_vars['post_type']))) {
        return $search;
    }

    $search_ids = [];
    $terms = explode(',', sanitize_text_field($wp->query_vars['s'])); // Sanitize input

    foreach ($terms as $term) {
        if (is_admin() && is_numeric($term)) {
            $search_ids[] = absint($term);
        }

        $term = wc_clean($term);
        $sku_to_parent_id = $wpdb->get_col($wpdb->prepare(
            "SELECT p.post_parent as post_id FROM {$wpdb->posts} as p JOIN {$wpdb->postmeta} pm ON p.ID = pm.post_id WHERE pm.meta_key='_sku' AND pm.meta_value LIKE %s AND p.post_parent <> 0 GROUP BY p.post_parent",
            '%' . $wpdb->esc_like($term) . '%'
        ));
        $sku_to_id = $wpdb->get_col($wpdb->prepare(
            "SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key='_sku' AND meta_value LIKE %s",
            '%' . $wpdb->esc_like($term) . '%'
        ));

        $search_ids = array_merge($search_ids, array_map('absint', $sku_to_parent_id), array_map('absint', $sku_to_id));
    }

    $search_ids = array_filter($search_ids);
    if (!empty($search_ids)) {
        $search = str_replace(')))', ") OR ({$wpdb->posts}.ID IN (" . implode(',', $search_ids) . "))))", $search);
    }

    return $search;
}

if (! function_exists('urna_search_only_title')) {
    function urna_search_only_title($search, $wp_query)
    {
        if (! empty($search) && ! empty($wp_query->query_vars['search_terms'])) {
            global $wpdb;

            $q = $wp_query->query_vars;
            $n = ! empty($q['exact']) ? '' : '%';

            $search = array();

            foreach (( array ) $q['search_terms'] as $term) {
                $search[] = $wpdb->prepare("$wpdb->posts.post_title LIKE %s", $n . $wpdb->esc_like($term) . $n);
            }

            if (! is_user_logged_in()) {
                $search[] = "$wpdb->posts.post_password = ''";
            }

            $search = ' AND ' . implode(' AND ', $search);
        }

        return $search;
    }
}

if (! function_exists('urna_search_options')) {
    function urna_search_options($search, $wp_query)
    {
        $options = apply_filters('urna_search_in_options', 10, 2);

        if ($options === 'only_title') {
            $where = urna_search_only_title($search, $wp_query);
        } elseif ($options === 'all') {
            $where = urna_search_sku($search);
        }

        return $where;
    }
    add_filter('posts_search', 'urna_search_options', 20, 2);
}

if (! function_exists('wp_body_open')) :
    /**
     * Fire the wp_body_open action.
     *
     * Added for backwards compatibility to support pre 5.2.0 WordPress versions.
     *
     * @since Urna 1.5
     */
    function wp_body_open()
    {
        /**
         * Triggered after the opening <body> tag.
         *
         * @since Urna 1.5
         */
        do_action('wp_body_open');
    }
endif;
