<?php if (! defined('URNA_THEME_DIR')) {
    exit('No direct script access allowed');
}

if (! function_exists('urna_clear_product_transients')) {
    function urna_clear_product_transients() {
        delete_transient('urna_product_categories_all');
        delete_transient('urna_product_tags');
    }
    add_action('created_term', 'urna_clear_product_transients');
    add_action('edited_term', 'urna_clear_product_transients');
}

if (! function_exists('urna_clear_menu_transients')) {
    function urna_clear_menu_transients() {
        delete_transient('urna_menus_default');
        global $sitepress;
        $current_lang = apply_filters('wpml_current_language', null);
        delete_transient('urna_menus_wpml_' . $current_lang);
    }
    add_action('wp_update_nav_menu', 'urna_clear_menu_transients');
}

if (! function_exists('urna_clear_pages_transient')) {
    function urna_clear_pages_transient($post_id) {
        $post_type = get_post_type($post_id);
        if ($post_type === 'pages') {
            delete_transient('urna_available_pages');
        }
    }
    add_action('save_post', 'urna_clear_pages_transient');
    add_action('delete_post', 'urna_clear_pages_transient');
}

if (! function_exists('urna_clear_product_countdown_transient')) {
    function urna_clear_product_countdown_transient() {
        delete_transient('urna_products_countdown');
    }
    add_action('save_post_product', 'urna_clear_product_countdown_transient');
}

if (! function_exists('urna_clear_elementor_rows_transient')) {
    function urna_clear_elementor_rows_transient() {
        delete_transient('urna_elementor_rows');
    }
    add_action('urna_admin_elementor_rows', 'urna_clear_elementor_rows_transient');
}

if (! function_exists('urna_clear_elementor_columns_transient')) {
    function urna_clear_elementor_columns_transient() {
        delete_transient('urna_elementor_columns');
    }
    add_action('urna_admin_elementor_columns', 'urna_clear_elementor_columns_transient');
}

if ( ! function_exists( 'urna_clear_transient' ) ) {
	function urna_clear_transient() {
		delete_transient( 'urna-hash-time' );
	} 
	add_action( 'wp_update_nav_menu_item', 'urna_clear_transient', 11, 1 );
}


if (!function_exists('urna_clear_footer_cache_on_save')) {
    function urna_clear_footer_cache_on_save($post_id, $post, $update) {

        $footer_slug = get_post_field('post_name', $post_id);
        if ($footer_slug) {
            $cache_key = 'urna_footer_content_' . md5($footer_slug);
            delete_transient($cache_key);
        }
    }
    add_action('save_post_tbay_footer', 'urna_clear_footer_cache_on_save', 10, 3);
}


if (!function_exists('urna_handle_tbay_customtab_save')) {
    /**
     * Handle save_post for tbay_customtab custom post type
     */
    function urna_handle_tbay_customtab_save($post_id) {
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return;
        }

        // Get the tab name
        $tab_name = get_the_title($post_id);
        
        // Generate cache key matching your original function
        $cache_key = 'urna_custom_tab_' . md5($tab_name);
        
        // Clear the cache for this specific tab
        delete_transient($cache_key);
    }

    // Hook into save_post_tbay_customtab action
    add_action('save_post_tbay_customtab', 'urna_handle_tbay_customtab_save');
}

if (!function_exists('urna_clear_on_sale_products_transient')) {
    /**
     * Clear on-sale products transient when product stock, post, or sale price changes.
     *
     * @param int|WC_Product $product Product ID or object (depending on hook)
     */
    function urna_clear_on_sale_products_transient() {
        delete_transient('urna_on_sale_products_options');
        delete_transient('urna_products_countdown');
    }

    // Hook into WooCommerce product stock change
    add_action('woocommerce_product_set_stock', 'urna_clear_on_sale_products_transient');

    // Hook into product post save
    add_action('save_post_product', 'urna_clear_on_sale_products_transient');

    // Hook into WooCommerce sale price update
    add_action('woocommerce_update_product_sale_price', 'urna_clear_on_sale_products_transient');
}


if (!function_exists('urna_clear_tbay_megamenu_transient_on_save')) {
    /**
     * Delete transients related to a specific tbay_megamenu post when updated.
     */
    function urna_clear_tbay_megamenu_transient_on_save($post_id) {
        // Check if this is an autosave or revision
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return;
        }


        $transient_list = get_option('urna_megamenu_transients', array());

        foreach ($transient_list as $transient_name => $related_post_id) {
            if ($related_post_id == $post_id) {
                delete_transient($transient_name);
                unset($transient_list[$transient_name]);
            }
        }

        update_option('urna_megamenu_transients', $transient_list);
    }
    add_action('save_post_tbay_megamenu', 'urna_clear_tbay_megamenu_transient_on_save');
}


if (!function_exists('urna_clear_quickview_transient')) {
    /**
     * Delete quickview transient when product is updated.
     */
    function urna_clear_quickview_transient($product_id) {
        if (get_post_type($product_id) !== 'product' || get_post_status($product_id) === 'auto-draft') {
            return;
        }

        $cache_key = 'urna_quickview_' . $product_id;
        delete_transient($cache_key);
    }
    add_action('woocommerce_update_product', 'urna_clear_quickview_transient', 10, 1);
    add_action('save_post', 'urna_clear_quickview_transient', 10, 1);
}
