<?php
if (!defined('ABSPATH') || function_exists('Urna_Elementor_Carousel_Base')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;

abstract class Urna_Elementor_Carousel_Base extends Urna_Elementor_Responsive_Base
{
    public function get_name()
    {
        return 'urna-carousel';
    }

    /**
     * Get available rows options with caching.
     *
     * @return array Rows options.
     */
    private function get_rows() {
        $cache_key = 'urna_elementor_rows';
        $rows = get_transient($cache_key);

        if (false === $rows) {
            $rows = apply_filters('urna_admin_elementor_rows', [
                1 => 1,
                2 => 2,
                3 => 3,
            ]);
            set_transient($cache_key, $rows, YEAR_IN_SECONDS);
        }

        return $rows;
    }

    /**
     * Add carousel controls.
     *
     * @param array $condition Conditions for controls visibility.
     */
    protected function add_control_carousel($condition = []) {
        $this->register_section_carousel_options($condition);
        $this->register_section_style_navigation($condition);
        $this->register_section_style_pagination($condition);
    }

    /**
     * Register carousel options section.
     *
     * @param array $condition Conditions for section visibility.
     */
    private function register_section_carousel_options($condition = []) {
        $this->start_controls_section(
            'section_carousel_options',
            [
                'label' => esc_html__('Carousel Options', 'urna'),
                'type' => Controls_Manager::SECTION,
                'condition' => $condition,
            ]
        );

        $this->add_control(
            'rows',
            [
                'label' => esc_html__('Rows', 'urna'),
                'type' => Controls_Manager::SELECT,
                'default' => 1,
                'options' => $this->get_rows(),
            ]
        );

        $this->add_control(
            'navigation',
            [
                'label' => esc_html__('Navigation', 'urna'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'urna'),
                'label_off' => esc_html__('Hide', 'urna'),
                'default' => 'yes',
                'description' => esc_html__('Show/hide navigation arrows', 'urna'),
            ]
        );

        $this->add_control(
            'pagination',
            [
                'label' => esc_html__('Pagination', 'urna'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'urna'),
                'label_off' => esc_html__('Hide', 'urna'),
                'default' => 'no',
                'description' => esc_html__('Show/hide pagination dots', 'urna'),
            ]
        );

        $this->add_control(
            'loop',
            [
                'label' => esc_html__('Infinite Loop', 'urna'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'urna'),
                'label_off' => esc_html__('No', 'urna'),
                'default' => 'no',
                'description' => esc_html__('Enable/disable infinite loop', 'urna'),
            ]
        );

        $this->add_control(
            'auto',
            [
                'label' => esc_html__('Autoplay', 'urna'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'urna'),
                'label_off' => esc_html__('No', 'urna'),
                'default' => 'no',
                'description' => esc_html__('Enable/disable autoplay', 'urna'),
            ]
        );

        $this->add_control(
            'autospeed',
            [
                'label' => esc_html__('Autoplay Speed', 'urna'),
                'type' => Controls_Manager::NUMBER,
                'default' => 1000,
                'min' => 100,
                'max' => 10000,
                'step' => 100,
                'condition' => [
                    'auto' => 'yes',
                ],
                'description' => esc_html__('Speed in milliseconds', 'urna'),
            ]
        );

        $this->add_control(
            'disable_mobile',
            [
                'label' => esc_html__('Disable Carousel on Mobile', 'urna'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'urna'),
                'label_off' => esc_html__('No', 'urna'),
                'default' => 'yes',
                'description' => esc_html__('Disable carousel on mobile for faster loading', 'urna'),
            ]
        );

        $this->end_controls_section();
    }

   /**
     * Register navigation style section.
     *
     * @param array $condition Conditions for section visibility.
     */
    private function register_section_style_navigation($condition = []) {
        $this->start_controls_section(
            'section_style_navigation',
            [
                'label' => esc_html__('Navigation', 'urna'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => array_merge($condition, ['navigation' => 'yes']),
            ]
        );

        $this->add_responsive_control(
            'arrows_width',
            [
                'label' => esc_html__('Width', 'urna'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 80,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-arrow' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'arrows_height',
            [
                'label' => esc_html__('Height', 'urna'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 80,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-arrow' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-arrow i' => 'line-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'arrows_size_icon',
            [
                'label' => esc_html__('Icon Size', 'urna'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 50,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-arrow i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'arrows_position',
            [
                'label' => esc_html__('Position', 'urna'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-arrow.slick-prev' => 'left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-arrow.slick-next' => 'right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'arrows_radius',
            [
                'label' => esc_html__('Border Radius', 'urna'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-arrow' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('arrows_colors');

        $this->start_controls_tab(
            'arrows_color_normal',
            ['label' => esc_html__('Normal', 'urna')]
        );

        $this->add_control(
            'arrows_text_color',
            [
                'label' => esc_html__('Text Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-arrow i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'arrows_color_hover',
            ['label' => esc_html__('Hover', 'urna')]
        );

        $this->add_control(
            'arrows_text_color_hover',
            [
                'label' => esc_html__('Text Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-arrow:hover i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();
    }

    /**
     * Register pagination style section.
     *
     * @param array $condition Conditions for section visibility.
     */
    private function register_section_style_pagination($condition = []) {
        $this->start_controls_section(
            'section_style_pagination',
            [
                'label' => esc_html__('Pagination', 'urna'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => array_merge($condition, ['pagination' => 'yes']),
            ]
        );

        $this->add_responsive_control(
            'pagination_width',
            [
                'label' => esc_html__('Width', 'urna'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 6,
                        'max' => 50,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-dots li button' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'pagination_height',
            [
                'label' => esc_html__('Height', 'urna'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 6,
                        'max' => 50,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-dots li button' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'pagination_position',
            [
                'label' => esc_html__('Position', 'urna'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 150,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-dots' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'pagination_radius',
            [
                'label' => esc_html__('Border Radius', 'urna'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-dots li button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('pagination_colors');

        $this->start_controls_tab(
            'pagination_color_normal',
            ['label' => esc_html__('Normal', 'urna')]
        );

        $this->add_control(
            'pagination_color',
            [
                'label' => esc_html__('Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-dots li button' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'pagination_color_active',
            ['label' => esc_html__('Active', 'urna')]
        );

        $this->add_control(
            'pagination_color_active',
            [
                'label' => esc_html__('Color', 'urna'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tbay-element .owl-carousel .slick-dots li.slick-active button' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();
    }

    /**
     * Configure carousel settings.
     *
     * @param array $settings Carousel settings.
     */
    protected function settings_carousel($settings) {
        $defaults = [
            'column' => 4,
            'col_desktop' => 4,
            'col_desktopsmall' => 3,
            'column_tablet' => 3,
            'col_landscape' => 2,
            'column_mobile' => 2,
            'rows' => 1,
            'navigation' => 'yes',
            'pagination' => 'no',
            'loop' => 'no',
            'auto' => 'no',
            'autospeed' => 1000,
            'disable_mobile' => 'yes',
        ];

        $settings = wp_parse_args($settings, $defaults);

        $this->add_render_attribute('row', 'class', ['owl-carousel', 'scroll-init']);
        $this->add_render_attribute('row', [
            'data-carousel' => 'owl',
            'data-items' => (int) $settings['column'],
            'data-desktopslick' => (int) $settings['col_desktop'],
            'data-desktopsmallslick' => (int) $settings['col_desktopsmall'],
            'data-tabletslick' => (int) $settings['column_tablet'],
            'data-landscapeslick' => (int) $settings['col_landscape'],
            'data-mobileslick' => (int) $settings['column_mobile'],
            'data-rows' => (int) $settings['rows'],
            'data-nav' => $settings['navigation'] === 'yes' ? 'true' : 'false',
            'data-pagination' => $settings['pagination'] === 'yes' ? 'true' : 'false',
            'data-loop' => $settings['loop'] === 'yes' ? 'true' : 'false',
            'data-auto' => $settings['auto'] === 'yes' ? 'true' : 'false',
            'data-unslick' => $settings['disable_mobile'] === 'yes' ? 'true' : 'false',
        ]);

        if (!empty($settings['autospeed'])) {
            $this->add_render_attribute('row', 'data-autospeed', (int) $settings['autospeed']);
        }
    }
}
