<?php
if (!defined('ABSPATH') || function_exists('Urna_Elementor_Widget_Image')) {
    exit; // Exit if accessed directly.
}

use Elementor\Widget_Image;

abstract class Urna_Elementor_Widget_Image extends Widget_Image
{
    public function get_name_template()
    {
        return str_replace('tbay-', '', $this->get_name());
    }

    public function get_categories()
    {
        return [ 'urna-elements' ];
    }

    public function get_name()
    {
        return 'urna-image';
    }

    /**
     * Load and render a view template.
     *
     * @param string $tpl_slug Template slug.
     * @param string $tpl_name Template name.
     * @param array  $settings Settings array.
     */
    protected function get_view_template($tpl_slug, $tpl_name = '', $settings = []) {
        if (empty($settings)) {
            $settings = $this->get_settings_for_display();
        }

        $templates = [];
        $tpl_name = trim(str_replace('.php', '', $tpl_name), DIRECTORY_SEPARATOR);

        if (!empty($tpl_name)) {
            $templates[] = "elementor_templates/{$tpl_slug}-{$tpl_name}.php";
            $templates[] = "elementor_templates/{$tpl_slug}/{$tpl_name}.php";
        }
        $templates[] = "elementor_templates/{$tpl_slug}.php";

        $located = false;
        foreach ($templates as $template) {
            $template_path = URNA_THEMEROOT . '/' . $template;
            if (file_exists($template_path)) {
                $located = locate_template($template);
                break;
            }
        }

        if ($located) {
            include $located;
        } else {
            printf(
                '<div class="elementor-error">%s</div>',
                sprintf(
                    /* translators: %1$s is the template slug, %2$s is the template name */
                    esc_html__('Failed to load template with slug "%1$s" and name "%2$s".', 'urna'),
                    esc_html($tpl_slug),
                    esc_html($tpl_name)
                )
            );
        }
    }

/**
     * Render widget output.
     */
    protected function render() {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute('wrapper', 'class', [
            'tbay-element',
            'tbay-element-' . $this->get_name_template(),
        ]);

        $this->get_view_template($this->get_name_template(), '', $settings);
    }
}
