<?php
if (!defined('ABSPATH') || function_exists('Urna_Elementor_Responsive_Base')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;

abstract class Urna_Elementor_Responsive_Base extends Urna_Elementor_Widget_Base
{
    public function get_name()
    {
        return 'urna-responsive';
    }

    /**
     * Get available column options with caching.
     *
     * @return array Column options.
     */
    private function get_columns() {
        $cache_key = 'urna_elementor_columns';
        $columns = get_transient($cache_key);

        if (false === $columns) {
            $columns = apply_filters('urna_admin_elementor_columns', [
                1 => 1,
                2 => 2,
                3 => 3,
                4 => 4,
                5 => 5,
                6 => 6,
                7 => 7,
                8 => 8,
            ]);
            set_transient($cache_key, $columns, YEAR_IN_SECONDS);
        }

        return $columns;
    }

    /**
     * Register responsive controls.
     *
     * @param array $condition Conditions for section visibility.
     */
    protected function add_control_responsive($condition = []) {
        $this->start_controls_section(
            'section_responsive',
            [
                'label' => esc_html__('Responsive Settings', 'urna'),
                'type' => Controls_Manager::SECTION,
                'condition' => $condition,
            ]
        );

        $this->add_responsive_control(
            'column',
            [
                'label' => esc_html__('Columns', 'urna'),
                'type' => Controls_Manager::SELECT,
                'default' => 4,
                'options' => $this->get_columns(),
                'devices' => ['desktop', 'tablet', 'mobile'],
                'desktop_default' => 4,
                'tablet_default' => 3,
                'mobile_default' => 2,
                'description' => esc_html__('Number of columns for different screen sizes', 'urna'),
            ]
        );

        $this->add_control(
            'col_desktop',
            [
                'label' => esc_html__('Large Desktop Columns', 'urna'),
                'description' => esc_html__('Columns for screen width between 1200px and 1600px', 'urna'),
                'type' => Controls_Manager::SELECT,
                'default' => 4,
                'options' => $this->get_columns(),
            ]
        );

        $this->add_control(
            'col_desktopsmall',
            [
                'label' => esc_html__('Small Desktop Columns', 'urna'),
                'description' => esc_html__('Columns for screen width between 992px and 1199px', 'urna'),
                'type' => Controls_Manager::SELECT,
                'default' => 2,
                'options' => $this->get_columns(),
            ]
        );

        $this->add_control(
            'col_landscape',
            [
                'label' => esc_html__('Mobile Landscape Columns', 'urna'),
                'description' => esc_html__('Columns for screen width between 576px and 767px', 'urna'),
                'type' => Controls_Manager::SELECT,
                'default' => 2,
                'options' => $this->get_columns(),
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Configure responsive settings.
     *
     * @param array $settings Responsive settings.
     */
    protected function settings_responsive($settings) {
        $defaults = [
            'column' => 4,
            'col_desktop' => 4,
            'col_desktopsmall' => 2,
            'column_tablet' => 3,
            'col_landscape' => 2,
            'column_mobile' => 2,
        ];

        $settings = wp_parse_args($settings, $defaults);

        $this->add_render_attribute('row', 'class', ['row', 'grid']);
        $this->add_render_attribute('row', [
            'data-xlgdesktop' => (int) $settings['column'],
            'data-desktop' => (int) $settings['col_desktop'],
            'data-desktopsmall' => (int) $settings['col_desktopsmall'],
            'data-tablet' => (int) $settings['column_tablet'],
            'data-landscape' => (int) $settings['col_landscape'],
            'data-mobile' => (int) $settings['column_mobile'],
        ]);
    }
}
