<?php

if (! defined('ABSPATH') || function_exists('Urna_Elementor_Product_CountDown')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;

class Urna_Elementor_Product_CountDown extends Urna_Elementor_Carousel_Base
{
    /**
     * Get widget name.
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'tbay-product-count-down';
    }

    /**
     * Get widget title.
     *
     * @return string Widget title.
     */
    public function get_title() {
        return esc_html__('Urna Product Countdown', 'urna');
    }

    /**
     * Get widget categories.
     *
     * @return array Widget categories.
     */
    public function get_categories() {
        return ['urna-elements', 'woocommerce-elements'];
    }

    /**
     * Get widget icon.
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-countdown';
    }

    /**
     * Get script dependencies.
     *
     * @return array Script dependencies.
     */
    public function get_script_depends() {
        return ['slick', 'urna-slick', 'jquery-countdowntimer'];
    }

    /**
     * Get widget keywords.
     *
     * @return array Widget keywords.
     */
    public function get_keywords() {
        return ['woocommerce-elements', 'product', 'products', 'countdown'];
    }

    /**
     * Register widget controls.
     */
    protected function register_controls() {
        $this->register_controls_heading();
        $this->register_remove_heading_element();

        $this->start_controls_section(
            'general',
            [
                'label' => esc_html__('General', 'urna'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'countdown_title',
            [
                'label'       => esc_html__('Title Date', 'urna'),
                'type'        => Controls_Manager::TEXT,
                'default'     => esc_html__('Deal ends in:', 'urna'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'layout_type',
            [
                'label'   => esc_html__('Layout Type', 'urna'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'grid'     => esc_html__('Grid', 'urna'),
                    'carousel' => esc_html__('Carousel', 'urna'),
                ],
                'default' => 'grid',
            ]
        );

        $products = $this->get_available_products_countdown();

        if (!empty($products)) {
            $this->add_control(
                'products',
                [
                    'label'        => esc_html__('Products', 'urna'),
                    'type'         => Controls_Manager::SELECT2,
                    'options'      => $products,
                    'default'      => array_keys($products)[0] ?? '',
                    'multiple'     => true,
                    'save_default' => true,
                    'label_block'  => true,
                    'description'  => esc_html__('Only search for products with a countdown', 'urna'),
                ]
            );
        } else {
            $this->add_control(
                'html_products',
                [
                    'type'            => Controls_Manager::RAW_HTML,
                    'raw'             => sprintf(
                        /* translators: %s: URL to products admin screen */
                        __('You do not have any products with a countdown. <br>Go to the <strong><a href="%s" target="_blank">Products screen</a></strong> to create one.', 'urna'),
                        esc_url(admin_url('edit.php?post_type=product'))
                    ),
                    'separator'       => 'after',
                    'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
                ]
            );
        }

        $this->register_new_options_skin_kitchen();

        $this->end_controls_section();

        $this->add_control_responsive();
        $this->add_control_carousel(['layout_type!' => ['grid']]);
    }

    /**
     * Register additional options for 'kitchen' skin.
     */
    private function register_new_options_skin_kitchen() {
        if ('kitchen' !== urna_tbay_get_theme()) {
            return;
        }

        $this->add_control(
            'heading_banner',
            [
                'label'     => esc_html__('Banner', 'urna'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'show_banner',
            [
                'label'       => esc_html__('Display Banner?', 'urna'),
                'description' => esc_html__('Show or hide the banner', 'urna'),
                'type'        => Controls_Manager::SWITCHER,
                'default'     => 'yes',
            ]
        );

        $this->add_control(
            'banners',
            [
                'label'     => esc_html__('Banner', 'urna'),
                'type'      => Controls_Manager::GALLERY,
                'condition' => ['show_banner' => 'yes'],
                'default'   => [
                    ['url' => Elementor\Utils::get_placeholder_image_src()],
                ],
            ]
        );

        $this->add_control(
            'banner_link',
            [
                'label'       => esc_html__('External Link', 'urna'),
                'type'        => Controls_Manager::URL,
                'condition'   => ['show_banner' => 'yes'],
                'placeholder' => esc_html__('https://your-link.com', 'urna'),
                'default'     => ['url' => ''],
            ]
        );

        $this->add_control(
            'heading_menu',
            [
                'label'     => esc_html__('Menu', 'urna'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'show_menu',
            [
                'label'       => esc_html__('Display Menu?', 'urna'),
                'description' => esc_html__('Show or hide the menu', 'urna'),
                'type'        => Controls_Manager::SWITCHER,
                'default'     => 'yes',
            ]
        );

        $menus = $this->get_available_menus();

        if (!empty($menus)) {
            $this->add_control(
                'nav_menu',
                [
                    'label'        => esc_html__('Menu', 'urna'),
                    'type'         => Controls_Manager::SELECT,
                    'options'      => $menus,
                    'default'      => array_keys($menus)[0] ?? '',
                    'save_default' => true,
                    'separator'    => 'after',
                    'condition'    => ['show_menu' => 'yes'],
                    'description'  => sprintf(
                        /* translators: %s: URL to menus admin screen */
                        __('Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'urna'),
                        esc_url(admin_url('nav-menus.php'))
                    ),
                ]
            );
        } else {
            $this->add_control(
                'nav_menu',
                [
                    'type'            => Controls_Manager::RAW_HTML,
                    'raw'             => sprintf(
                        /* translators: %s: URL to menus admin screen */
                        __('<strong>There are no menus in your site.</strong><br>Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'urna'),
                        esc_url(admin_url('nav-menus.php?action=edit&menu=0'))
                    ),
                    'separator'       => 'after',
                    'condition'       => ['show_menu' => 'yes'],
                    'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
                ]
            );
        }
    }

    /**
     * Render banner content for countdown.
     */
    protected function render_content_banner_count_down() {
        $settings = $this->get_settings_for_display();
        if (empty($settings['show_banner']) || 'yes' !== $settings['show_banner'] || empty($settings['banners'])) {
            return;
        }

        $this->add_link_attributes('banner_link', $settings['banner_link']);
        ?>
        <div class="img-banner col-sm-6 col-md-8 col-lg-3 clearfix">
            <?php if (!empty($settings['banner_link']['url'])) : ?>
                <a <?php echo $this->get_render_attribute_string('banner_link'); ?>>
                    <?php $this->render_banner_images($settings['banners']); ?>
                </a>
            <?php else : ?>
                <?php $this->render_banner_images($settings['banners']); ?>
            <?php endif; ?>
        </div>
        <?php
    }

    /**
     * Render banner images.
     *
     * @param array $banners Array of banner image data.
     */
    private function render_banner_images($banners) {
        foreach ($banners as $banner) {
            if (!empty($banner['id'])) {
                echo wp_get_attachment_image($banner['id'], 'full', false, ['alt' => esc_attr__('Banner Image', 'urna')]);
            }
        }
    }

    /**
     * Render menu content for countdown.
     */
    protected function render_content_menu_count_down() {
        $settings = $this->get_settings_for_display();
        if (empty($settings['show_menu']) || 'yes' !== $settings['show_menu'] || empty($settings['nav_menu'])) {
            return;
        }

        $menu_id = sanitize_key($settings['nav_menu']);
        ?>
        <div class="custom-menu-wrapper col-sm-6 col-md-4 col-lg-3">
            <?php echo urna_get_custom_menu($menu_id); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
        </div>
        <?php
    }

    /**
     * Render product countdown content.
     */
    public function render_content_product_count_down() {
        $settings = $this->get_settings_for_display();
        $ids = $settings['products'] ?? [];

        if (empty($ids)) {
            printf('<div class="not-product-count-down">%s</div>', esc_html__('Please select products to display.', 'urna'));
            return;
        }

        $transient_name = 'urna_product_countdown_' . $this->get_id() . '_' . md5(serialize($ids));
        $cached_output = get_transient($transient_name);

        if (false === $cached_output) {
            $atts = ['ids' => is_array($ids) ? implode(',', array_map('intval', $ids)) : sanitize_text_field($ids)];
            $shortcode = new WC_Shortcode_Products($atts, 'products');
            $args = $shortcode->get_query_args();

            $args['post_status'] = 'publish';
            $args['no_found_rows'] = true;

            $loop = new WP_Query($args);
            if (!$loop->have_posts()) {
                return;
            }

            if ('carousel' === $settings['layout_type']) {
                $this->add_render_attribute('row', 'class', ['products', 'rows-' . esc_attr($settings['rows'])]);
            }

            ob_start();
            wc_get_template(
                "layout-products/{$settings['layout_type']}.php",
                [
                    'loop'            => $loop,
                    'countdown'       => true,
                    'countdown_title' => $settings['countdown_title'],
                    'layout_type'     => $settings['layout_type'],
                    'attr_row'        => $this->get_render_attribute_string('row'),
                ]
            );
            $cached_output = ob_get_clean();

            set_transient($transient_name, $cached_output, DAY_IN_SECONDS);

            wp_reset_postdata();
        }

        echo $cached_output; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    }
}

$widgets_manager->register(new Urna_Elementor_Product_CountDown());