<?php
if (!function_exists('urna_is_woocommerce_activated') || !urna_is_woocommerce_activated()) {
    return;
}

/**
 * Display "Delivery Return" button for single product.
 *
 * @param int $product_id Product ID.
 */
if (!function_exists('urna_the_delivery_return')) {
    function urna_the_delivery_return($product_id) {
        $delivery_return = urna_get_delivery_return_content($product_id);
        if (empty(trim($delivery_return))) {
            return;
        }

        wp_enqueue_script('jquery-magnific-popup');
        wp_enqueue_style('magnific-popup');

        $heading = apply_filters('urna_woo_product_delivery_return_heading', esc_html__('Delivery Return', 'urna'));
        $icon    = apply_filters('urna_woo_product_delivery_return_icon_class', 'tb-icon tb-icon-z-question');

        printf(
            '<li class="item tbay-delivery-return"><a href="#tbay-content-delivery-return" class="popup-button-open"><i class="%s"></i><span>%s</span></a></li>',
            esc_attr($icon),
            esc_html($heading)
        );
    }
}

/**
 * Helper function to get delivery return content.
 */
if (!function_exists('urna_get_delivery_return_content')) {
    function urna_get_delivery_return_content($product_id) {
        $delivery_return_type = maybe_unserialize(get_post_meta($product_id, '_urna_delivery_return_type', true));
        return !empty($delivery_return_type) && $delivery_return_type !== 'global' 
            ? maybe_unserialize(get_post_meta($product_id, '_urna_delivery_return', true)) 
            : maybe_unserialize(urna_tbay_get_config('single_delivery_return', ''));
    }
}

/**
 * Render "Delivery Return" popup content in footer.
 */
if (!function_exists('urna_the_delivery_return_content')) {
    add_action('wp_footer', 'urna_the_delivery_return_content', 60);
    function urna_the_delivery_return_content() {
        if (!is_product()) {
            return;
        }

        global $product;
        if (!$product) {
            return;
        }

        $delivery_return = urna_get_delivery_return_content($product->get_id());
        if (empty(trim($delivery_return))) {
            return;
        }

        wp_enqueue_script('jquery-magnific-popup');
        wp_enqueue_style('magnific-popup');

        ?>
        <div id="tbay-content-delivery-return" class="tbay-popup-content zoom-anim-dialog mfp-hide">
            <div class="content">
                <?php echo do_shortcode($delivery_return); ?>
            </div>
        </div>
        <?php
    }
}