<?php
/**
 * Exit if WooCommerce is not active.
 */
if (!function_exists('urna_is_Woocommerce_activated') || !urna_is_Woocommerce_activated()) {
    return;
}

/**
 * Setup WooCommerce image sizes after theme setup.
 */
if (!function_exists('urna_woocommerce_setup_size_image')) {
    add_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
    function urna_woocommerce_setup_size_image() {
        $thumbnail_width = 293;
        $main_image_width = 600;
        $cropping_custom_width = 1;
        $cropping_custom_height = 1;

        // Update WooCommerce image size options.
        $options = [
            'woocommerce_thumbnail_image_width'         => $thumbnail_width,
            'woocommerce_single_image_width'            => $main_image_width,
            'woocommerce_thumbnail_cropping'            => 'custom',
            'woocommerce_thumbnail_cropping_custom_width'  => $cropping_custom_width,
            'woocommerce_thumbnail_cropping_custom_height' => $cropping_custom_height,
        ];

        foreach ($options as $key => $value) {
            update_option($key, $value);
        }
    }
}

// Remove image size setup if media config is disabled globally.
if (urna_tbay_get_global_config('config_media', false)) {
    remove_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
}

/**
 * Customize Visual Composer columns for admin.
 *
 * @param array $output Default columns.
 * @return array Modified columns.
 */
if (!function_exists('urna_change_admin_visualcomposer_columns')) {
    add_filter('urna_admin_visualcomposer_columns', 'urna_change_admin_visualcomposer_columns');
    function urna_change_admin_visualcomposer_columns($output) {
        return range(1, 8);
    }
}

/**
 * Customize Visual Composer brands columns for admin.
 *
 * @param array $output Default columns.
 * @return array Modified columns.
 */
if (!function_exists('urna_change_admin_visualcomposer_brands_columns')) {
    add_filter('urna_admin_visualcomposer_brands_columns', 'urna_change_admin_visualcomposer_brands_columns');
    function urna_change_admin_visualcomposer_brands_columns($output) {
        return range(1, 10);
    }
}

/**
 * Customize add-to-cart icon.
 *
 * @return string Icon HTML.
 */
if (!function_exists('urna_skin_tbay_icon_add_cart')) {
    add_filter('urna_get_icon_add_to_cart', 'urna_skin_tbay_icon_add_cart', 2);
    function urna_skin_tbay_icon_add_cart() {
        return '<i class="linear-icon-bag2"></i>';
    }
}

/**
 * Adjust swatch variable position based on product layout.
 */
if (!function_exists('urna_change_swatch_variable')) {
    add_action('woocommerce_before_shop_loop_item_title', 'urna_change_swatch_variable', 15);
    function urna_change_swatch_variable() {
        $layout = apply_filters('urna_woo_config_product_layout', 'default');

        if ($layout === 'v7') {
            remove_action('urna_woo_before_shop_loop_item_caption', 'urna_tbay_woocommerce_variable', 5);
            add_action('urna_tbay_after_shop_loop_item_title', 'urna_tbay_woocommerce_variable', 15);
        }
    }
}