<?php
/**
 * Exit if WooCommerce is not active.
 */
if (!function_exists('urna_is_Woocommerce_activated') || !urna_is_Woocommerce_activated()) {
    return;
}

/**
 * Setup WooCommerce image sizes after theme setup.
 */
if (!function_exists('urna_woocommerce_setup_size_image')) {
    add_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
    function urna_woocommerce_setup_size_image() {
        $thumbnail_width        = 366;
        $main_image_width       = 600;
        $cropping_custom_width  = 1;
        $cropping_custom_height = 1;

        // Define image size options in an array for efficient updates.
        $image_options = [
            'woocommerce_thumbnail_image_width'         => $thumbnail_width,
            'woocommerce_single_image_width'            => $main_image_width,
            'woocommerce_thumbnail_cropping'            => 'custom',
            'woocommerce_thumbnail_cropping_custom_width'  => $cropping_custom_width,
            'woocommerce_thumbnail_cropping_custom_height' => $cropping_custom_height,
        ];

        // Batch update options to reduce database calls.
        foreach ($image_options as $key => $value) {
            update_option($key, $value);
        }
    }
}

// Remove image size setup if media config is disabled globally.
if (function_exists('urna_tbay_get_global_config') && urna_tbay_get_global_config('config_media', false)) {
    remove_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
}

/**
 * Customize countdown flash sale labels.
 */
if (!function_exists('urna_tbay_custom_countdown_flash_sale_labels')) {
    function urna_tbay_custom_countdown_flash_sale_labels($type) {
        $labels = [
            'day'  => esc_html__('days', 'urna'),
            'hour' => esc_html__('hours', 'urna'),
            'mins' => esc_html__('mins', 'urna'),
            'secs' => esc_html__('secs', 'urna'),
        ];

        return sprintf('<span class="label">%s</span>', $labels[$type] ?? '');
    }

    // Register filters for countdown labels.
    $countdown_filters = [
        'urna_tbay_countdown_flash_sale_day'  => 'day',
        'urna_tbay_countdown_flash_sale_hour' => 'hour',
        'urna_tbay_countdown_flash_sale_mins' => 'mins',
        'urna_tbay_countdown_flash_sale_secs' => 'secs',
    ];

    foreach ($countdown_filters as $filter => $type) {
        add_filter($filter, function() use ($type) {
            return urna_tbay_custom_countdown_flash_sale_labels($type);
        }, 10, 1);
    }
}