<?php
/**
 * Exit if WooCommerce is not active.
 */
if (!function_exists('urna_is_Woocommerce_activated') || !urna_is_Woocommerce_activated()) {
    return;
}

/**
 * Setup WooCommerce image sizes after theme setup.
 */
if (!function_exists('urna_woocommerce_setup_size_image')) {
    add_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
    function urna_woocommerce_setup_size_image() {
        $thumbnail_width        = 465;
        $main_image_width       = 600;
        $cropping_custom_width  = 1;
        $cropping_custom_height = 1;

        // Define image size options in an array for efficient updates.
        $image_options = [
            'woocommerce_thumbnail_image_width'         => $thumbnail_width,
            'woocommerce_single_image_width'            => $main_image_width,
            'woocommerce_thumbnail_cropping'            => 'custom',
            'woocommerce_thumbnail_cropping_custom_width'  => $cropping_custom_width,
            'woocommerce_thumbnail_cropping_custom_height' => $cropping_custom_height,
        ];

        // Batch update options to reduce database calls.
        foreach ($image_options as $key => $value) {
            update_option($key, $value);
        }
    }
}

// Remove image size setup if media config is disabled globally.
if (function_exists('urna_tbay_get_global_config') && urna_tbay_get_global_config('config_media', false)) {
    remove_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
}

// Adjust the position of the rating in the product loop.
remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 15);
add_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5);

/**
 * Customize the categories count item label.
 *
 * @return string Label for category item count.
 */
if (!function_exists('urna_tbay_custom_categories_count_item')) {
    add_filter('urna_tbay_categories_count_item', 'urna_tbay_custom_categories_count_item', 10, 1);
    function urna_tbay_custom_categories_count_item() {
        return esc_html__('products', 'urna');
    }
}