<?php
/**
 * Exit if WooCommerce is not active.
 */
if (!function_exists('urna_is_Woocommerce_activated') || !urna_is_Woocommerce_activated()) {
    return;
}

/**
 * Setup WooCommerce image sizes after theme setup.
 */
if (!function_exists('urna_woocommerce_setup_size_image')) {
    add_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
    function urna_woocommerce_setup_size_image() {
        $thumbnail_width        = 313;
        $main_image_width       = 600;
        $cropping_custom_width  = 1;
        $cropping_custom_height = 1;

        // Define image size options in an array for efficient updates.
        $image_options = [
            'woocommerce_thumbnail_image_width'         => $thumbnail_width,
            'woocommerce_single_image_width'            => $main_image_width,
            'woocommerce_thumbnail_cropping'            => 'custom',
            'woocommerce_thumbnail_cropping_custom_width'  => $cropping_custom_width,
            'woocommerce_thumbnail_cropping_custom_height' => $cropping_custom_height,
        ];

        // Batch update options to reduce database calls.
        foreach ($image_options as $key => $value) {
            update_option($key, $value);
        }
    }
}

// Remove image size setup if media config is disabled globally.
if (function_exists('urna_tbay_get_global_config') && urna_tbay_get_global_config('config_media', false)) {
    remove_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
}

/**
 * Add subtitle field to product general options.
 */
if (!function_exists('urna_woo_subtitle_field')) {
    add_action('woocommerce_product_options_general_product_data', 'urna_woo_subtitle_field');
    function urna_woo_subtitle_field() {
        woocommerce_wp_text_input([
            'id'          => '_subtitle',
            'label'       => esc_html__('Subtitle', 'urna'),
            'placeholder' => esc_html__('Subtitle....', 'urna'),
            'description' => esc_html__('Enter the subtitle.', 'urna'),
        ]);
    }
}

/**
 * Save subtitle field data when product is saved.
 *
 * @param int $post_id Product ID.
 */
if (!function_exists('urna_woo_subtitle_field_save')) {
    add_action('woocommerce_process_product_meta', 'urna_woo_subtitle_field_save');
    function urna_woo_subtitle_field_save($post_id) {
        if (isset($_POST['_subtitle'])) {
            update_post_meta($post_id, '_subtitle', sanitize_text_field($_POST['_subtitle']));
        }
    }
}

/**
 * Display product subtitle in shop loop.
 */
if (!function_exists('urna_woo_get_subtitle')) {
    add_action('urna_woo_before_shop_loop_item_caption', 'urna_woo_get_subtitle', 5);
    function urna_woo_get_subtitle() {
        global $product;

        if (!$product || !($subtitle = get_post_meta($product->get_id(), '_subtitle', true))) {
            return;
        }

        printf('<div class="tbay-subtitle">%s</div>', esc_html($subtitle));
    }
}