<?php
/**
 * Exit if WooCommerce is not active.
 */
if (!function_exists('urna_is_Woocommerce_activated') || !urna_is_Woocommerce_activated()) {
    return;
}

/**
 * Setup WooCommerce image sizes after theme setup.
 */
if (!function_exists('urna_woocommerce_setup_size_image')) {
    add_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
    function urna_woocommerce_setup_size_image() {
        $thumbnail_width        = 414;
        $main_image_width       = 600;
        $cropping_custom_width  = 1;
        $cropping_custom_height = 1;

        // Define image size options in an array for efficient updates.
        $image_options = [
            'woocommerce_thumbnail_image_width'         => $thumbnail_width,
            'woocommerce_single_image_width'            => $main_image_width,
            'woocommerce_thumbnail_cropping'            => 'custom',
            'woocommerce_thumbnail_cropping_custom_width'  => $cropping_custom_width,
            'woocommerce_thumbnail_cropping_custom_height' => $cropping_custom_height,
        ];

        // Batch update options to reduce database calls.
        foreach ($image_options as $key => $value) {
            update_option($key, $value);
        }
    }
}

// Remove image size setup if media config is disabled globally.
if (function_exists('urna_tbay_get_global_config') && urna_tbay_get_global_config('config_media', false)) {
    remove_action('after_setup_theme', 'urna_woocommerce_setup_size_image');
}

/**
 * Modify sale label display based on product layout.
 */
if (!function_exists('urna_change_label_sale')) {
    add_action('urna_woocommerce_before_product_block_grid', 'urna_change_label_sale', 15);
    function urna_change_label_sale() {
        $layout = apply_filters('urna_woo_config_product_layout', 10, 2);

        // Only proceed if layout is 'v5'.
        if ($layout === 'v5') {
            add_action('woocommerce_after_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
        }
    }
}