<?php

if (!urna_is_Woocommerce_activated()) {
    return;
}

define('URNA_WOOCOMMERCE_ACTIVED', true);

// Add custom product data tab
if (!function_exists('urna_add_custom_product_data_tab')) {
  /**
   * Add a custom tab to WooCommerce product data tabs
   *
   * @since 1.0
   * @param array $product_data_tabs Existing product data tabs
   * @return array Modified product data tabs
   */
  function urna_add_custom_product_data_tab($product_data_tabs) {
      $product_data_tabs['urna-options-tab'] = [
          'label'    => esc_html__('Urna Options', 'urna'),
          'target'   => 'urna_product_data',
          'class'    => [],
          'priority' => 100,
      ];
      return $product_data_tabs;
  }
  add_filter('woocommerce_product_data_tabs', 'urna_add_custom_product_data_tab', 80);
}


// Add custom fields to product data panel
if (!function_exists('urna_options_woocom_product_data_fields')) {
  /**
   * Add custom fields to WooCommerce product data panel
   *
   * @since 1.0
   */
  function urna_options_woocom_product_data_fields() {
      echo '<div id="urna_product_data" class="panel woocommerce_options_panel"><div class="options_group">';

      // Video URL field
      woocommerce_wp_text_input(apply_filters('urna_tbay_woocommerce_simple_url_video_args', [
          'id'          => '_video_url',
          'label'       => esc_html__('Featured Video URL', 'urna'),
          'placeholder' => esc_html__('Video URL', 'urna'),
          'desc_tip'    => true,
          'description' => esc_html__('Enter the video URL at https://vimeo.com/ or https://www.youtube.com/', 'urna'),
      ]));

      // Size Guide fields
      echo '<div class="options_group">';
      woocommerce_wp_select(apply_filters('urna_tbay_woo_size_guide_type_args', [
          'id'          => '_urna_size_guide_type',
          'label'       => esc_html__('Size Guide Type', 'urna'),
          'options'     => [
              'global'    => esc_html__('Global Setting', 'urna'),
              'customize' => esc_html__('Customize', 'urna'),
          ],
          'desc_tip'    => true,
          'description' => esc_html__('Global Setting uses the Size Guide from theme options', 'urna'),
      ]));
      woocommerce_wp_textarea_input(apply_filters('urna_tbay_woo_size_guide_args', [
          'id'            => '_urna_size_guide',
          'label'         => esc_html__('Size Guide Customize', 'urna'),
          'desc_tip'      => true,
          'description'   => esc_html__('Enter an optional shortcode or custom text', 'urna'),
          'wrapper_class' => 'show_size_guide_customize',
      ]));
      echo '</div>';

      // Delivery Return fields
      echo '<div class="options_group">';
      woocommerce_wp_select(apply_filters('urna_tbay_woo_delivery_return_type_args', [
          'id'          => '_urna_delivery_return_type',
          'label'       => esc_html__('Delivery Return Type', 'urna'),
          'options'     => [
              'global'    => esc_html__('Global Setting', 'urna'),
              'customize' => esc_html__('Customize', 'urna'),
          ],
          'desc_tip'    => true,
          'description' => esc_html__('Global Setting uses the Delivery Return from theme options', 'urna'),
      ]));
      woocommerce_wp_textarea_input(apply_filters('urna_tbay_woo_delivery_return_args', [
          'id'            => '_urna_delivery_return',
          'label'         => esc_html__('Delivery Return Customize', 'urna'),
          'desc_tip'      => true,
          'description'   => esc_html__('Enter an optional shortcode or custom text', 'urna'),
          'wrapper_class' => 'show_delivery_return_customize',
      ]));
      echo '</div>';

      do_action('urna_woocommerce_options_product_data');
      echo '</div></div>';
  }
  add_action('woocommerce_product_data_panels', 'urna_options_woocom_product_data_fields');
}
  
  // Save custom product data fields
if (!function_exists('urna_options_woocom_save_proddata_custom_fields')) {
  /**
   * Save custom product data fields
   *
   * @since 1.0
   * @param WC_Product $product Product object
   */
  function urna_options_woocom_save_proddata_custom_fields($product) {
      $fields = [
          '_video_url'              => 'text',
          '_urna_size_guide_type'   => 'text',
          '_urna_size_guide'        => 'textarea',
          '_urna_delivery_return_type' => 'text',
          '_urna_delivery_return'   => 'textarea',
      ];

      foreach ($fields as $field => $type) {
          $value = isset($_POST[$field]) ? wp_unslash($_POST[$field]) : '';
          $old_value = $product->get_meta($field);

          if ($value !== $old_value) {
              $product->update_meta_data($field, $type === 'text' ? sanitize_text_field($value) : wp_kses_post($value));
          }
      }
  }
  add_action('woocommerce_admin_process_product_object', 'urna_options_woocom_save_proddata_custom_fields', 10, 1);
}

// Size Guide Image Metabox Output
if (!function_exists('urna_size_guide_metabox_output')) {
  /**
   * Output Size Guide image metabox
   *
   * @since 1.0
   * @param WP_Post $post Post object
   */
  function urna_size_guide_metabox_output($post) {
      $product_image = get_post_meta($post->ID, '_product_size_guide_image', true) ?: '';
      if (!$product_image && metadata_exists('post', $post->ID, '_product_size_guide_image')) {
          $attachment_ids = get_posts([
              'post_parent'    => $post->ID,
              'numberposts'    => -1,
              'post_type'      => 'attachment',
              'orderby'        => 'menu_order',
              'order'          => 'ASC',
              'post_mime_type' => 'image',
              'fields'         => 'ids',
              'meta_key'       => '_woocommerce_size_guide_image',
              'meta_value'     => '1',
          ]);
          $attachment_ids = array_diff($attachment_ids, [get_post_thumbnail_id()]);
          $product_image = implode(',', $attachment_ids);
      }

      $attachments = array_filter(explode(',', $product_image));
      ?>
      <div id="product_size_guide_images_container">
          <ul class="product_size_guide_images">
              <?php
              if (!empty($attachments)) {
                  foreach ($attachments as $key => $attachment_id) {
                      if ($key !== 0) continue; // Only keep the first image
                      $attachment = wp_get_attachment_image($attachment_id, 'thumbnail');
                      if (empty($attachment)) continue;

                      echo '<li class="image" data-attachment_id="' . esc_attr($attachment_id) . '">' .
                           $attachment .
                           '<ul class="actions"><li><a href="#" class="delete tips" data-tip="' . esc_attr__('Remove product image', 'urna') . '">' . esc_html__('Remove product image', 'urna') . '</a></li></ul></li>';
                  }
              }
              ?>
          </ul>
          <input type="hidden" id="product_size_guide_image" name="product_size_guide_image" value="<?php echo esc_attr($product_image); ?>" />
      </div>
      <p class="add_product_size_guide_images hide-if-no-js">
          <a href="#" data-choose="<?php esc_attr_e('Add Images to Product Size Guide', 'urna'); ?>" 
             data-update="<?php esc_attr_e('Add to image', 'urna'); ?>" 
             data-delete="<?php esc_attr_e('Delete image', 'urna'); ?>" 
             data-text="<?php esc_attr_e('Remove product image', 'urna'); ?>">
              <?php esc_html_e('Add product Size Guide view images', 'urna'); ?>
          </a>
      </p>
      <?php
  }
}

// Save Size Guide Image Metabox
if (!function_exists('urna_proccess_size_guide_view_metabox')) {
  /**
   * Save Size Guide image metabox data
   *
   * @since 1.0
   * @param int $post_id Post ID
   */
  function urna_proccess_size_guide_view_metabox($post_id) {
      $attachment_ids = isset($_POST['product_size_guide_image']) ? wc_clean($_POST['product_size_guide_image']) : '';
      update_post_meta($post_id, '_product_size_guide_image', $attachment_ids);
  }
  add_action('woocommerce_process_product_meta', 'urna_proccess_size_guide_view_metabox', 50, 2);
}

// Get Size Guide Attachment IDs
if (!function_exists('urna_get_size_guide_attachment_ids')) {
  /**
   * Retrieve Size Guide image attachment IDs
   *
   * @since 1.0
   * @return array Attachment IDs
   */
  function urna_get_size_guide_attachment_ids() {
      global $post;
      if (!$post) return [];
      
      $product_image = get_post_meta($post->ID, '_product_size_guide_image', true);
      return apply_filters('woocommerce_product_size_guide_attachment_ids', array_filter(explode(',', $product_image), 'wp_attachment_is_image'));
  }
}

// Attribute Dropdown Template
if (!function_exists('urna_swatch_attribute_template')) {
  /**
   * Output attribute dropdown for swatches
   *
   * @since 1.0
   * @param WP_Post $post Post object
   */
  function urna_swatch_attribute_template($post) {
      $attribute_post_id = get_post_meta($post->ID, '_urna_attribute_select', true) ?: '';
      ?>
      <select name="urna_attribute_select" class="urna_attribute_taxonomy">
          <option value="" <?php selected($attribute_post_id, ''); ?>><?php esc_html_e('Global Setting', 'urna'); ?></option>
          <?php
          $attribute_taxonomies = wc_get_attribute_taxonomies();
          foreach ($attribute_taxonomies as $tax) {
              $attribute_taxonomy_name = wc_attribute_taxonomy_name($tax->attribute_name);
              $label = $tax->attribute_label ?: $tax->attribute_name;
              echo '<option value="' . esc_attr($attribute_taxonomy_name) . '" ' . selected($attribute_post_id, $attribute_taxonomy_name, false) . '>' . esc_html($label) . '</option>';
          }
          ?>
      </select>
      <?php
  }
}


// Save Attribute Dropdown
if (!function_exists('urna_attribute_dropdown_save')) {
  /**
   * Save attribute dropdown selection
   *
   * @since 1.0
   * @param int $post_id Post ID
   */
  function urna_attribute_dropdown_save($post_id) {
      if (isset($_POST['urna_attribute_select'])) {
          update_post_meta($post_id, '_urna_attribute_select', sanitize_text_field($_POST['urna_attribute_select']));
      }
  }
  add_action('woocommerce_process_product_meta', 'urna_attribute_dropdown_save', 30, 2);
}

// Single Layout Dropdown Template
if (!function_exists('urna_single_select_single_layout_template')) {
  /**
   * Output single layout dropdown
   *
   * @since 1.0
   * @param WP_Post $post Post object
   */
  function urna_single_select_single_layout_template($post) {
      $layout_post_id = get_post_meta($post->ID, '_urna_single_layout_select', true) ?: '';
      $layout_selects = apply_filters('urna_layout_select_filters', [
          'full-width-vertical'   => esc_html__('Image Vertical', 'urna'),
          'full-width-horizontal' => esc_html__('Image Horizontal', 'urna'),
          'full-width-stick'      => esc_html__('Image Stick', 'urna'),
          'full-width-gallery'    => esc_html__('Image Gallery', 'urna'),
          'full-width-carousel'   => esc_html__('Image Carousel', 'urna'),
          'full-width-full'       => esc_html__('Image Full', 'urna'),
          'full-width-centered'   => esc_html__('Image Centered', 'urna'),
          'left-main'             => esc_html__('Left - Main Sidebar', 'urna'),
          'main-right'            => esc_html__('Main - Right Sidebar', 'urna'),
      ]);
      ?>
      <select name="urna_layout_select" class="urna_single_layout_taxonomy">
          <option value="" <?php selected($layout_post_id, ''); ?>><?php esc_html_e('Global Setting', 'urna'); ?></option>
          <?php
          foreach ($layout_selects as $key => $select) {
              echo '<option value="' . esc_attr($key) . '" ' . selected($layout_post_id, $key, false) . '>' . esc_html($select) . '</option>';
          }
          ?>
      </select>
      <?php
  }
}


// Save Single Layout Dropdown
if (!function_exists('urna_single_select_dropdown_save')) {
  /**
   * Save single layout dropdown selection
   *
   * @since 1.0
   * @param int $post_id Post ID
   */
  function urna_single_select_dropdown_save($post_id) {
      if (isset($_POST['urna_layout_select'])) {
          update_post_meta($post_id, '_urna_single_layout_select', sanitize_text_field($_POST['urna_layout_select']));
      }
  }
  add_action('woocommerce_process_product_meta', 'urna_single_select_dropdown_save', 30, 2);
}