<?php

if (!urna_is_Woocommerce_activated()) {
    return;
}

/**
 * Display category image on category archive with caching
 */
if (!function_exists('urna_woocommerce_category_image')) {
    function urna_woocommerce_category_image() {
        if (!is_product_category() || is_search()) {
            return;
        }

        global $wp_query;
        $cat = $wp_query->get_queried_object();
        $thumbnail_id = get_term_meta($cat->term_id, 'thumbnail_id', true);
        
        if (!$thumbnail_id) {
            return;
        }

        // Add transient caching
        $cache_key = 'urna_category_image_' . $cat->term_id;
        $image = get_transient($cache_key);
        
        if (!$image) {
            $image = wp_get_attachment_url($thumbnail_id);
            set_transient($cache_key, $image, WEEK_IN_SECONDS);
        }

        if ($image) {
            printf(
                '<img src="%s" alt="%s" />',
                esc_url($image),
                esc_attr($cat->name)
            );
        }
    }
    add_action('woocommerce_archive_description', 'urna_woocommerce_category_image', 2);
}


/**
 * Product top archive sidebar
 */
if (!function_exists('urna_woocommerce_product_top_archive')) {
    function urna_woocommerce_product_top_archive() {
        if (is_product() || is_search()) {
            return;
        }

        $active = apply_filters('urna_sidebar_top_archive', true);
        $sidebar_id = 'product-top-archive';

        if ($active && is_active_sidebar($sidebar_id)) {
            ?>
            <aside id="sidebar-top-archive" class="sidebar top-archive-content">
                <?php dynamic_sidebar($sidebar_id); ?>
            </aside>
            <?php
        }
    }
    add_action('woocommerce_before_main_content', 'urna_woocommerce_product_top_archive', 10);
}

/**
 * Remove description and image conditionally
 */
if (!function_exists('urna_woocommerce_remove_des_image')) {
    function urna_woocommerce_remove_des_image() {
        $active = apply_filters('urna_woo_pro_des_image', true);
        
        if (!$active) {
            remove_action('woocommerce_archive_description', 'woocommerce_taxonomy_archive_description', 10);
            remove_action('woocommerce_archive_description', 'woocommerce_product_archive_description', 10);
            remove_action('woocommerce_archive_description', 'urna_woocommerce_category_image', 2);
        }
    }
    add_action('woocommerce_before_main_content', 'urna_woocommerce_remove_des_image', 20);
}

/**
 * Control product archives title display
 */
if (!function_exists('urna_woocommerce_remove_title_product_archives')) {
    function urna_woocommerce_remove_title_product_archives($show_title) {
        $active = apply_filters('urna_woo_title_product_archives', true);
        return is_search() ? true : $active;
    }
    add_filter('woocommerce_show_page_title', 'urna_woocommerce_remove_title_product_archives');
}

/**
 * AJAX filter button
 */
if (!function_exists('urna_woocommerce_ajax_filter_button')) {
    function urna_woocommerce_ajax_filter_button() {
        $active = apply_filters('urna_woo_ajax_filter', true);
        
        if (!$active) {
            return;
        }
        
        ?>
        <div id="tbay-ajax-filter-btn" class="tbay-ajax-filter-btn hidden-xs hidden-sm">
            <button class="btn">
                <i class="linear-icon-equalizer filter-icon"></i>
                <?php echo esc_html__('Filter', 'urna'); ?>
                <i class="linear-icon-chevron-down"></i>
            </button>
        </div>
        <?php
    }
    add_action('woocommerce_before_shop_loop', 'urna_woocommerce_ajax_filter_button', 20);
}

/**
 * AJAX filter sidebar
 */
if (!function_exists('urna_woocommerce_ajax_filter_sidebar')) {
    function urna_woocommerce_ajax_filter_sidebar() {
        $active = apply_filters('urna_woo_ajax_filter', true);
        
        if (!$active) {
            return;
        }
        
        ?>
        <div id="tbay-ajax-filter-sidebar" class="ajax-filter-sidebar">
            <?php echo do_shortcode('[woof]'); ?>
        </div>
        <?php
    }
    add_action('woocommerce_before_shop_loop', 'urna_woocommerce_ajax_filter_sidebar', 30);
}