<?php

if (!urna_is_Woocommerce_activated()) {
    return;
}

// Remove heading tab single product
if (!function_exists('urna_product_description_heading')) {
    add_filter('woocommerce_product_description_heading', 'urna_product_description_heading');
    function urna_product_description_heading() {
        return '';
    }
}

if (! function_exists('urna_woocommerce_setup_support')) {
    add_action('after_setup_theme', 'urna_woocommerce_setup_support');
    function urna_woocommerce_setup_support()
    {
        add_theme_support('wc-product-gallery-zoom');
        add_theme_support('wc-product-gallery-lightbox');
        add_theme_support('wc-product-gallery-slider');

        if (class_exists('YITH_Woocompare')) {
            update_option('yith_woocompare_compare_button_in_products_list', 'no');
            update_option('yith_woocompare_compare_button_in_product_page', 'no');
        }

        if (class_exists('YITH_WCWL')) {
            update_option('yith_wcwl_button_position', 'shortcode');
        }
        
        add_filter('woocommerce_get_image_size_gallery_thumbnail', function ($size) {
            $tbay_thumbnail_width       = get_option('tbay_woocommerce_thumbnail_image_width', 100);
            $tbay_thumbnail_height      = get_option('tbay_woocommerce_thumbnail_image_height', 100);
            $tbay_thumbnail_cropping    = get_option('tbay_woocommerce_thumbnail_cropping', 'yes');
            $tbay_thumbnail_cropping    = ($tbay_thumbnail_cropping == 'yes') ? true : false;

            return array(
                'width'  => $tbay_thumbnail_width,
                'height' => $tbay_thumbnail_height,
                'crop'   => $tbay_thumbnail_cropping,
            );
        });

        $ptreviews_width       = get_option('tbay_photo_reviews_thumbnail_image_width', 100);
        $ptreviews_height      = get_option('tbay_photo_reviews_thumbnail_image_height', 100);
        $ptreviews_cropping    = get_option('tbay_photo_reviews_thumbnail_image_cropping', 'yes');

        $ptreviews_cropping    = ($ptreviews_cropping == 'yes') ? true : false;

        add_image_size('tbay_photo_reviews_thumbnail_image', $ptreviews_width, $ptreviews_height, $ptreviews_cropping);
    }
}

/**
 * Add custom photo reviews size to reduction array
 */
if (!function_exists('urna_woocommerce_photo_reviews_reduce_array')) {
    add_filter('woocommerce_photo_reviews_reduce_array', 'urna_woocommerce_photo_reviews_reduce_array', 10, 1);
    function urna_woocommerce_photo_reviews_reduce_array($reduce) {
        $reduce[] = 'tbay_photo_reviews_thumbnail_image';
        return $reduce;
    }
}

/**
 * Display share box on single product page
 */
if (!function_exists('urna_tbay_woocommerce_share_box')) {
    add_action('woocommerce_single_product_summary', 'urna_tbay_woocommerce_share_box', 50);
    function urna_tbay_woocommerce_share_box() {
        if (wp_is_mobile() || !urna_tbay_get_config('enable_code_share', false) || !urna_tbay_get_config('enable_product_social_share', false)) {
            return;
        }

        if (urna_tbay_get_config('select_share_type') === 'custom') {
            $image = get_the_post_thumbnail_url(get_the_ID(), 'full');
            urna_custom_share_code(get_the_title(), get_permalink(), esc_url($image));
        } else {
            echo '<div class="tbay-woo-share"><div class="addthis_inline_share_toolbox"></div></div>';
        }
    }
}


/**
 * Add classes to single product wrapper
 */
if (!function_exists('urna_tbay_woocommerce_class_single_product')) {
    add_filter('woo_class_single_product', 'urna_tbay_woocommerce_class_single_product');
    function urna_tbay_woocommerce_class_single_product($styles = '') {
        global $product;
        if (!$product) {
            return $styles;
        }

        $attachment_ids = $product->get_gallery_image_ids();
        $sidebar_configs = urna_tbay_get_woocommerce_layout_configs();
        $images_layout = $sidebar_configs['thumbnail'] ?? 'horizontal';
        $active_stick = (!empty($attachment_ids) && $images_layout === 'stick') ? ' active-stick' : '';

        switch ($images_layout) {
            case 'centered':
                $styles = ' style-stick style-centered';
                break;
            case 'full':
                $styles = ' style-full';
                break;
            default:
                $styles = " style-{$images_layout}";
                break;
        }


        $cart_style = urna_get_mobile_form_cart_style();
        if ($product->get_type() === 'external') {
            $cart_style = 'default';
        }

        return $styles . " form-cart-{$cart_style}{$active_stick}";
    }
}


/**
 * Customize product tabs style
 */
if (!function_exists('urna_tbay_woocommerce_tabs_style_product')) {
    add_filter('woo_tabs_style_single_product', 'urna_tbay_woocommerce_tabs_style_product');
    function urna_tbay_woocommerce_tabs_style_product($tabs_layout = 'tabs') {
        if (!is_singular('product')) {
            return $tabs_layout;
        }
        return isset($_GET['tabs_product']) ? sanitize_text_field($_GET['tabs_product']) : urna_tbay_get_config('style_single_tabs_style', 'tabs');
    }
}

/**
 * Product countdown timer
 */
if (!function_exists('urna_woo_product_single_time_countdown')) {
    add_action('woocommerce_before_add_to_cart_form', 'urna_woo_product_single_time_countdown', 28);
    function urna_woo_product_single_time_countdown() {
        global $product;
        if (!$product || !$product->is_on_sale()) {
            return;
        }

        $countdown = isset($_GET['countdown']) ? sanitize_text_field($_GET['countdown']) : urna_tbay_get_config('enable_product_countdown', false);
        if (!$countdown) {
            return;
        }

        $time_sale = get_post_meta($product->get_id(), '_sale_price_dates_to', true);
        if (!$time_sale) {
            return;
        }

        wp_enqueue_script('jquery-countdowntimer');
        $id = urna_tbay_random_key();
        $date = gmdate('m-d-Y-H-i-s', $time_sale);
        $labels = [
            'days'  => apply_filters('urna_single_time_countdown_day', esc_html__('d', 'urna')),
            'hours' => apply_filters('urna_single_time_countdown_hour', esc_html__('h', 'urna')),
            'mins'  => apply_filters('urna_single_time_countdown_mins', esc_html__('m', 'urna')),
            'secs'  => apply_filters('urna_single_time_countdown_secs', esc_html__('s', 'urna')),
        ];
        ?>
        <div class="tbay-time-wrapper">
            <div class="time tbay-time">
                <div class="title"><?php esc_html_e('Deal end in: ', 'urna'); ?></div>
                <div class="tbay-countdown" data-id="<?php echo esc_attr($id); ?>-<?php echo esc_attr($product->get_id()); ?>" id="countdown-<?php echo esc_attr($id); ?>-<?php echo esc_attr($product->get_id()); ?>" data-countdown="countdown" data-date="<?php echo esc_attr($date); ?>" data-days="<?php echo esc_attr($labels['days']); ?>" data-hours="<?php echo esc_attr($labels['hours']); ?>" data-mins="<?php echo esc_attr($labels['mins']); ?>" data-secs="<?php echo esc_attr($labels['secs']); ?>"></div>
            </div>
            <?php if ($product->get_manage_stock()) {
                $total_sales = (int) $product->get_total_sales();
                $stock_quantity = (int) $product->get_stock_quantity();
                $total_quantity = $stock_quantity > 0 ? $total_sales + $stock_quantity : 0;
                $percent_sold = $total_quantity ? ($total_sales / $total_quantity) * 100 : 0; ?>
                <div class="stock">
                    <span class="tb-sold"><?php echo $stock_quantity > 0 ? esc_html__('Sold', 'urna') . " : <span class='totals-sold'>{$total_sales}</span>" : esc_html__('Sold out', 'urna'); ?></span>
                    <?php if ($percent_sold > 0) : ?>
                        <div class="progress">
                            <div class="progress-bar active" role="progressbar" style="width: <?php echo esc_attr($percent_sold); ?>%"></div>
                        </div>
                    <?php endif; ?>
                </div>
            <?php } ?>
        </div>
        <?php
    }
}

/**
 * Product navigation display mode
 */
if (!function_exists('urna_tbay_woocommerce_product_nav_display_mode')) {
    add_filter('urna_woo_nav_display_mode', 'urna_tbay_woocommerce_product_nav_display_mode');
    function urna_tbay_woocommerce_product_nav_display_mode($mode = 'image') {
        return isset($_GET['display_nav_mode']) ? sanitize_text_field($_GET['display_nav_mode']) : urna_tbay_get_config('product_nav_display_mode', 'image');
    }
}

/**
 * Render product navigation
 */
if (!function_exists('urna_render_product_nav')) {
    function urna_render_product_nav($post, $position) {
        if (!$post) {
            return;
        }


        $link = esc_url(get_permalink($post));
        $img = has_post_thumbnail($post) ? get_the_post_thumbnail($post, 'woocommerce_gallery_thumbnail') : '';
        $content = ($position === 'left') ? "<a class='img-link' href='{$link}'>" . trim($img) . "</a>" : (($position === 'right') ? "<a class='img-link' href='{$link}'>" . trim($img) . "</a>" : '');
        printf(
            '<div class="%s psnav">%s<div class="product_single_nav_inner single_nav"><a href="%s"><span class="name-pr">%s</span></a></div></div>',
            esc_attr($position),
            $content,
            $link,
            esc_html($post->post_title)
        );
    }
}


/**
 * Product navigation with images
 */
if (!function_exists('urna_woo_product_nav_image')) {
    add_action('woocommerce_before_single_product_summary', 'urna_woo_product_nav_image', 1);
    function urna_woo_product_nav_image() {
        if (!urna_tbay_get_config('show_product_nav', false) ) {
            return;
        }

        $prev = get_previous_post();
        $next = get_next_post();
        ?>
        <div class="product-nav pull-right">
            <div class="link-images visible-lg">
                <?php
                urna_render_product_nav($prev, 'left');
                urna_render_product_nav($next, 'right');
                ?>
            </div>
        </div>
        <?php
    }
}


/**
 * Product navigation with icons
 */
if (!function_exists('urna_woo_product_nav_icon')) {
    function urna_woo_product_nav_icon() {
        if (!urna_tbay_get_config('show_product_nav', false) || !is_singular('product') || apply_filters('urna_woo_nav_display_mode', 'image') === 'image') {
            return;
        }

        $prev = get_previous_post();
        $next = get_next_post();

        $output = '<div class="product-nav-icon pull-right">';
        $output .= '<div class="link-icons">';
        $output .= urna_render_product_nav_icon($prev, 'left');
        $output .= urna_render_product_nav_icon($next, 'right');
        $output .= '</div>';

        $output .= '</div>';

        return $output;
    }
}

/**
 * Render product navigation icon
 */
if (!function_exists('urna_render_product_nav_icon')) {
    function urna_render_product_nav_icon($post, $position) {
        if (!$post) {
            return '';
        }

        $product = wc_get_product($post->ID);
        $link = esc_url(get_permalink($post));
        $img = has_post_thumbnail($post) ? get_the_post_thumbnail($post, 'woocommerce_gallery_thumbnail') : '';
        $text = ($position === 'left') ? "<a class='img-link left' href='{$link}'><span class='product-btn-icon'></span>" . esc_html__('Prev', 'urna') . "</a>" : "<a class='img-link right' href='{$link}'>" . esc_html__('Next', 'urna') . "<span class='product-btn-icon'></span></a>";
        $image_content = ($position === 'left') ? "<a class='img-link' href='{$link}'>" . trim($img) . "</a>" : (($position === 'right') ? "<a class='img-link' href='{$link}'>" . trim($img) . "</a>" : '');
        return sprintf(
            '<div class="%s-icon icon-wrapper"><div class="text">%s</div><div class="image psnav">%s<div class="product_single_nav_inner single_nav">%s</div>%s</div></div>',
            esc_attr($position),
            $text,
            $image_content,
            urna_product_nav_inner_title_price($post, $product, $link),
            $image_content
        );
    }
}

/**
 * Render navigation title and price
 */
if (!function_exists('urna_product_nav_inner_title_price')) {
    function urna_product_nav_inner_title_price($post, $product, $link) {
        $is_catalog = get_post_meta($product->get_id(), '_catalog', true) === 'yes';
        $price = !$is_catalog ? "<span class='price'>{$product->get_price_html()}</span>" : '';
        return sprintf('<a href="%s"><span class="name-pr">%s</span>%s</a>', esc_url($link), esc_html($post->post_title), $price);
    }
}

if (!function_exists('urna_product_nav_inner_title_price')) {
    function urna_product_nav_inner_title_price($post, $product, $link)
    {
        $ouput = "<a href=". esc_url($link) .">";
        $ouput .= "<span class='name-pr'>". esc_html($post->post_title) ."</span>";

        $is_catalog = (get_post_meta($product->get_id(), '_catalog', true) == 'yes') ? 'yes' : '';

        if ($is_catalog !== 'yes') {
            $ouput .=  "<span class='price'>" . $product->get_price_html() . "</span>";
        }

        $ouput .=  "</a>";

        return $ouput;
    }
}

/**
 * Sticky menu bar configuration
 */
if (!function_exists('urna_tbay_woocommerce_product_menu_bar')) {
    add_filter('woo_product_menu_bar', 'urna_tbay_woocommerce_product_menu_bar');
    function urna_tbay_woocommerce_product_menu_bar($menu_bar = false) {
        return isset($_GET['sticky_menu_bar']) ? filter_var($_GET['sticky_menu_bar'], FILTER_VALIDATE_BOOLEAN) : urna_tbay_get_config('enable_sticky_menu_bar', false);
    }
}

/**
 * Check if sticky menu bar should be active
 */
if (!function_exists('urna_active_sticky_menu_bar')) {
    function urna_active_sticky_menu_bar() {
        return apply_filters('woo_active_product_menu_bar', !wp_is_mobile(), 1);
    }
}
/**Sticky Menu Bar**/

/**
 * Sticky menu bar display
 */
if (!function_exists('urna_sticky_menu_bar')) {
    if (urna_active_sticky_menu_bar()) {
        add_action('woocommerce_before_single_product', 'urna_sticky_menu_bar', 30);
        add_action('urna_sticky_menu_bar_product_summary', 'urna_woocommerce_single_title', 5);
        add_action('urna_sticky_menu_bar_product_summary', 'woocommerce_template_loop_rating', 10);
        add_action('urna_sticky_menu_bar_product_summary', 'urna_woo_product_single_one_page', 15);
        add_action('urna_sticky_menu_bar_product_price_cart', 'woocommerce_template_single_price', 5);
        add_action('urna_sticky_menu_bar_product_price_cart', 'urna_sticky_menu_bar_custom_add_to_cart', 10);
    }
    function urna_sticky_menu_bar() {
        if (!apply_filters('woo_product_menu_bar', false)) {
            return;
        }

        global $post;
        $img = has_post_thumbnail($post) ? get_the_post_thumbnail($post, 'woocommerce_gallery_thumbnail') : '';
        ?>
        <?php do_action('urna_before_sticky_menu_bar_product_price_cart'); ?>
        <div id="sticky-menu-bar">
            <div class="container">
                <div class="row">
                    <div class="menu-bar-left col-md-7">
                        <div class="media">
                            <div class="media-left media-top pull-left"><?php echo $img; ?></div>
                            <div class="media-body"><?php do_action('urna_sticky_menu_bar_product_summary'); ?></div>
                        </div>
                    </div>
                    <div class="menu-bar-right col-md-5"><?php do_action('urna_sticky_menu_bar_product_price_cart'); ?></div>
                </div>
            </div>
        </div>
        <?php do_action('urna_after_sticky_menu_bar_product_price_cart'); ?>
        <?php
    }
}

/**
 * Custom add to cart button for sticky menu
 */
if (!function_exists('urna_sticky_menu_bar_custom_add_to_cart')) {
    function urna_sticky_menu_bar_custom_add_to_cart() {
        global $product;
        if (!$product->is_in_stock()) {
            echo wc_get_stock_html($product);
        } else {
            printf('<a id="sticky-custom-add-to-cart" href="javascript:void(0);">%s</a>', esc_html($product->single_add_to_cart_text()));
        }
    }
}

/**
 * One-page navigation for single product
 */
if (!function_exists('urna_woo_product_single_one_page')) {
    function urna_woo_product_single_one_page() {
        if (!apply_filters('woo_product_menu_bar', false)) {
            return;
        }

        wp_enqueue_script('jquery-onepagenav');
        $header = urna_tbay_get_config('select-header-page', 'default') === 'default' ? '#tbay-header' : '#tbay-customize-header';
        ?>
        <ul id="onepage-single-product" class="nav nav-pills">
            <li class="onepage-overview"><a href="<?php echo esc_attr($header); ?>"><?php esc_html_e('Overview', 'urna'); ?></a></li>
            <li class="onepage-description"><a href="#woocommerce-tabs"><?php esc_html_e('Specifications', 'urna'); ?></a></li>
            <?php if (urna_tbay_get_config('enable_product_releated', true)) : ?>
                <li><a href="#product-related"><?php esc_html_e('Related Products', 'urna'); ?></a></li>
            <?php endif; ?>
        </ul>
        <?php
    }
}

/**
 * Add body class for single product one-page
 */
if (!function_exists('urna_woo_product_body_class_single_one_page')) {
    add_filter('body_class', 'urna_woo_product_body_class_single_one_page', 99);
    function urna_woo_product_body_class_single_one_page($classes) {
        if (apply_filters('woo_product_menu_bar', false) && is_product()) {
            $classes[] = 'tbay-body-menu-bar';
        }
        return $classes;
    }
}

/**
 * Add wrapper before add to cart button
 */
if (!function_exists('urna_add_product_id_before_add_to_cart_form')) {
    add_action('woocommerce_before_add_to_cart_button', 'urna_add_product_id_before_add_to_cart_form', 99);
    function urna_add_product_id_before_add_to_cart_form() {
        global $product;
        $class = (intval(urna_tbay_get_config('enable_buy_now', false)) && $product->get_type() !== 'external') ? 'has-buy-now' : '';
        printf('<div id="shop-now" class="%s">', esc_attr($class));
    }
}

/**
 * Close wrapper after add to cart button
 */
if (!function_exists('urna_close_after_add_to_cart_form')) {
    add_action('woocommerce_after_add_to_cart_button', 'urna_close_after_add_to_cart_form', 99);
    function urna_close_after_add_to_cart_form() {
        echo '</div>';
    }
}

/**
 * Remove additional information heading
 */
if (!function_exists('urna_supermaket_product_additional_information_heading')) {
    add_filter('woocommerce_product_additional_information_heading', 'urna_supermaket_product_additional_information_heading');
    function urna_supermaket_product_additional_information_heading() {
        return '';
    }
}

/**
 * Customize related products args
 */
if (!function_exists('urna_related_products_args')) {
    add_filter('woocommerce_output_related_products_args', 'urna_related_products_args');
    function urna_related_products_args($args) {
        $args['posts_per_page'] = absint(urna_tbay_get_config('number_product_releated', 4));
        return $args;
    }
}


/**
 * Display product video
 */
if (!function_exists('urna_tbay_get_video_product')) {
    add_action('woocommerce_before_single_product_summary', 'urna_tbay_get_video_product', 30);
    function urna_tbay_get_video_product() {
        global $post;
        $video_url = get_post_meta($post->ID, '_video_url', true);
        if (!$video_url) {
            return;
        }

        $video = urna_tbay_VideoUrlType($video_url);
        $url = $video['video_type'] === 'youtube' ? "https://www.youtube.com/embed/{$video['video_id']}?autoplay=1" : "https://player.vimeo.com/video/{$video['video_id']}?autoplay=1";
        $icon = '<i class="linear-icon-play" aria-hidden="true"></i>' . esc_html__('Watch Video', 'urna');
        ?>
        <div class="modal fade" id="productvideo">
            <div class="modal-dialog">
                <div class="modal-content tbay-modalContent">
                    <div class="modal-body">
                        <div class="close-button">
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">&times;</span></button>
                        </div>
                        <div class="embed-responsive embed-responsive-16by9">
                            <iframe class="embed-responsive-item"></iframe>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <button type="button" class="tbay-modalButton" data-toggle="modal" data-tbaySrc="<?php echo esc_attr($url); ?>" data-tbayWidth="640" data-tbayHeight="480" data-target="#productvideo" data-tbayVideoFullscreen="true"><?php echo $icon; ?></button>
        <?php
    }
}

/**
 * Add size guide hooks
 */
if (!function_exists('urna_add_product_size_guide_hook')) {
    add_action('woocommerce_before_single_product', 'urna_add_product_size_guide_hook', 100);
    function urna_add_product_size_guide_hook() {
        global $post;
        if (!urna_tbay_get_config('enable_size_guide', false) || !metadata_exists('post', $post->ID, '_product_size_guide_image') || !get_post_meta($post->ID, '_product_size_guide_image', true)) {
            return;
        }
        add_filter('woocommerce_reset_variations_link', 'urna_add_product_size_guide', 25);
        add_filter('woocommerce_before_single_variation', 'urna_add_product_size_guide_content', 25);
    }
}

/**
 * Display size guide button
 */
if (!function_exists('urna_add_product_size_guide')) {
    function urna_add_product_size_guide($content = '') {
        global $post;
        if (!urna_tbay_get_config('enable_size_guide', false) || !metadata_exists('post', $post->ID, '_product_size_guide_image')) {
            return $content;
        }

        $attachment_id = get_post_meta($post->ID, '_product_size_guide_image', true);
        $title = esc_html(urna_tbay_get_config('size_guide_title', 'Size Guide'));
        $icon = urna_tbay_get_config('size_guide_icon', '') ? '<i class="' . esc_attr(urna_tbay_get_config('size_guide_icon', '')) . '"></i>' : '';
        ?>
        <button type="button" class="btn-size-guide" data-toggle="modal" data-target="#product-size-guide"><?php echo $icon . $title; ?></button>
        <a class="reset_variations" href="#"><?php esc_html_e('Clear', 'urna'); ?></a>
        <?php
        return $content;
    }
}


/**
 * Size guide modal content
 */
if (!function_exists('urna_add_product_size_guide_content')) {
    function urna_add_product_size_guide_content() {
        global $post;
        if (!urna_tbay_get_config('enable_size_guide', false) || !metadata_exists('post', $post->ID, '_product_size_guide_image') || !($attachment_id = get_post_meta($post->ID, '_product_size_guide_image', true))) {
            return;
        }

        $title = esc_html(urna_tbay_get_config('size_guide_title', 'Size Guide'));
        $image = wp_get_attachment_image($attachment_id, 'full');
        ?>
        <div id="product-size-guide" class="modal fade" role="dialog">
            <div class="modal-dialog">
                <div class="modal-content">
                    <div class="modal-header">
                        <button type="button" class="close" data-dismiss="modal"><i class="linear-icon-cross2"></i></button>
                        <h4 class="modal-title"><?php echo $title; ?></h4>
                    </div>
                    <div class="modal-body"><?php echo $image; ?></div>
                </div>
            </div>
        </div>
        <?php
    }
}

/**
 * Custom tab builder
 */
if (!function_exists('urna_tbay_display_custom_tab_builder')) {
    function urna_tbay_display_custom_tab_builder($tab_name) {
        $cache_key = 'urna_custom_tab_' . md5($tab_name);
        $cached = get_transient($cache_key);
        if ($cached !== false) {
            return $cached;
        }

        $args = [
            'name'        => sanitize_text_field($tab_name),
            'post_type'   => 'tbay_customtab',
            'post_status' => 'publish',
            'posts_per_page' => 1,
        ];
        $posts = get_posts($args);
        $tab = [];
        foreach ($posts as $post) {
            $tab['title'] = esc_html($post->post_title);
            $tab['content'] = urna_elementor_is_activated() && Elementor\Plugin::instance()->documents->get($post->ID)->is_built_with_elementor() ?
                Elementor\Plugin::instance()->frontend->get_builder_content_for_display($post->ID) :
                do_shortcode($post->post_content);
        }
        set_transient($cache_key, $tab, WEEK_IN_SECONDS);
        return $tab;
    }
}

/**
 * Remove review tab if disabled
 */
if (!function_exists('urna_tbay_product_review_tab')) {
    add_filter('woocommerce_product_tabs', 'urna_tbay_product_review_tab', 100);
    function urna_tbay_product_review_tab($tabs) {
        if (!urna_tbay_get_config('enable_product_review_tab', true) && isset($tabs['reviews'])) {
            unset($tabs['reviews']);
        }
        return $tabs;
    }
}


/**
 * Add custom product tab
 */
if (!function_exists('urna_product_aditional_tab')) {
    add_filter('woocommerce_product_tabs', 'urna_product_aditional_tab', 110);
    function urna_product_aditional_tab($tabs) {
        if (!urna_tbay_get_config('enable_custom_tab', false) || !($tab = urna_tbay_get_config('custom_tab_type', '')) || !($output_tab = urna_tbay_display_custom_tab_builder($tab))) {
            return $tabs;
        }
        $tabs['custom_tab'] = [
            'title'    => esc_html($output_tab['title']),
            'priority' => 50,
            'callback' => 'urna_product_custom_tab_content',
        ];
        return $tabs;
    }
}

if (!function_exists('urna_product_custom_tab_content')) {
    function urna_product_custom_tab_content()
    {
        $tab = urna_tbay_get_config('custom_tab_type', '');

        $output_tab       =    urna_tbay_display_custom_tab_builder($tab);

        echo trim($output_tab['content']);
    }
}


/**
 * Adjust share box position for full/carousel layouts
 */
if (!function_exists('urna_product_single_edit_layout_width_full')) {
    add_action('woocommerce_before_single_product', 'urna_product_single_edit_layout_width_full');
    function urna_product_single_edit_layout_width_full() {
        $sidebar_configs = urna_tbay_get_woocommerce_layout_configs();
        $images_layout = $sidebar_configs['thumbnail'] ?? 'horizontal';
        if (in_array($images_layout, ['full', 'carousel'])) {
            remove_action('woocommerce_single_product_summary', 'urna_tbay_woocommerce_share_box', 50);
            add_action('woocommerce_single_product_summary', 'urna_tbay_woocommerce_share_box', 35);
        }
    }
}

/**
 * Enable/disable zoom image
 */
if (!function_exists('urna_tbay_enable_zoom_image')) {
    add_filter('urna_zoom_image', 'urna_tbay_enable_zoom_image', 120);
    function urna_tbay_enable_zoom_image($active = true) {
        return isset($_GET['enable_zoom_image']) ? filter_var($_GET['enable_zoom_image'], FILTER_VALIDATE_BOOLEAN) : urna_tbay_get_config('enable_zoom_image', true);
    }
}

/**
 * Apply zoom image setting
 */
if (!function_exists('urna_remove_support_zoom_image')) {
    add_filter('woocommerce_single_product_zoom_enabled', 'urna_remove_support_zoom_image');
    function urna_remove_support_zoom_image() {
        return apply_filters('urna_zoom_image', true);
    }
}

/**
 * Quick view details button
 */
if (!function_exists('urna_quick_view_view_details_btn')) {
    add_action('urna_woocommerce_after_product_thumbnails', 'urna_quick_view_view_details_btn', 10);
    function urna_quick_view_view_details_btn() {
        if (!urna_tbay_get_config('enable_quickview', true)) {
            return;
        }
        global $product;
        printf('<div class="details-btn-wrapper"><a class="view-details-btn" href="%s">%s</a></div>', esc_url($product->get_permalink()), esc_html__('View details', 'urna'));
    }
}

/**
 * Custom HTML before/after add to cart
 */
if (!function_exists('urna_action_woocommerce_before_add_to_cart_button')) {
    add_action('woocommerce_before_add_to_cart_form', 'urna_action_woocommerce_before_add_to_cart_button', 10);
    function urna_action_woocommerce_before_add_to_cart_button() {
        echo do_shortcode(urna_tbay_get_config('html_before_add_to_cart_btn', ''));
    }
}

if (!function_exists('urna_action_woocommerce_after_add_to_cart_button')) {
    add_action('woocommerce_after_add_to_cart_form', 'urna_action_woocommerce_after_add_to_cart_button', 999);
    function urna_action_woocommerce_after_add_to_cart_button() {
        echo do_shortcode(urna_tbay_get_config('html_after_add_to_cart_btn', ''));
    }
}

if (!function_exists('urna_action_woocommerce_before_inner_product_summary')) {
    add_action('woocommerce_single_product_summary', 'urna_action_woocommerce_before_inner_product_summary', 1);
    function urna_action_woocommerce_before_inner_product_summary() {
        echo do_shortcode(urna_tbay_get_config('html_before_inner_product_summary', ''));
    }
}
  
if (!function_exists('urna_action_woocommerce_after_inner_product_summary')) {
    add_action('woocommerce_single_product_summary', 'urna_action_woocommerce_after_inner_product_summary', 999);
    function urna_action_woocommerce_after_inner_product_summary() {
        echo do_shortcode(urna_tbay_get_config('html_after_inner_product_summary', ''));
    }
}
  
  
if (!function_exists('urna_action_woocommerce_after_product_summary')) {
    add_action('woocommerce_after_single_product', 'urna_action_woocommerce_after_product_summary', 10);
    function urna_action_woocommerce_after_product_summary() {
        echo do_shortcode(urna_tbay_get_config('html_after_product_summary', ''));
    }
}
  
if (!function_exists('urna_action_woocommerce_before_product_summary')) {
    add_action('woocommerce_before_single_product', 'urna_action_woocommerce_before_product_summary', 1);
    function urna_action_woocommerce_before_product_summary() {
        echo do_shortcode(urna_tbay_get_config('html_before_product_summary', ''));
    }
}

/**
 * Display total sales count
 */
if (!function_exists('urna_single_product_add_total_sales_count')) {
    add_action('urna_woo_after_single_rating', 'urna_single_product_add_total_sales_count', 10);
    function urna_single_product_add_total_sales_count() {
        global $product;
        if (!urna_tbay_get_config('enable_total_sales', true) || $product->get_type() === 'external') {
            return;
        }
        $count = (float) get_post_meta($product->get_id(), 'total_sales', true);
        printf('<span class="rate-sold"><span class="count">%s</span> <span class="sold-text">%s</span></span>', number_format_i18n($count), esc_html__('sold', 'urna'));
    }
}

/**
 * Custom photo reviews sizes
 */
if (!function_exists('urna_photo_reviews_thumbnail_photo_size')) {
    add_filter('woocommerce_photo_reviews_thumbnail_photo', 'urna_photo_reviews_thumbnail_photo_size', 10, 2);
    function urna_photo_reviews_thumbnail_photo_size($image_src, $image_post_id) {
        return wp_get_attachment_image_src($image_post_id, 'tbay_photo_reviews_thumbnail_image')[0] ?? $image_src;
    }
}

if (!function_exists('urna_photo_reviews_large_photo_size')) {
    add_filter('woocommerce_photo_reviews_large_photo', 'urna_photo_reviews_large_photo_size', 10, 2);
    function urna_photo_reviews_large_photo_size($image_src, $image_post_id) {
        return wp_get_attachment_image_src($image_post_id, 'full')[0] ?? $image_src;
    }
}

/**
 * Mobile add to cart content
 */
if (!function_exists('urna_mobile_add_add_to_cart_button_content')) {
    function urna_mobile_add_add_to_cart_button_content() {
        if (urna_catalog_mode_active()) {
            return;
        }
        global $product;
        ?>
        <div id="mobile-close-infor"><i class="linear-icon-cross2"></i></div>
        <div class="mobile-infor-wrapper">
            <div class="media">
                <div class="media-left"><?php echo $product->get_image('woocommerce_gallery_thumbnail', ['class' => 'mobile-infor-img']); ?></div>
                <div class="media-body">
                    <div class="infor-body"><?php urna_mobile_infor_body($product); ?></div>
                </div>
            </div>
        </div>
        <?php
    }
}

if (!function_exists('urna_mobile_infor_body')) {
    function urna_mobile_infor_body($product) {
        printf('<p class="price">%s</p>%s', $product->get_price_html(), wc_get_stock_html($product));
    }
}

if (!function_exists('urna_mobile_add_before_add_to_cart_button')) {
    add_action('woocommerce_before_add_to_cart_button', 'urna_mobile_add_before_add_to_cart_button', 10);
    function urna_mobile_add_before_add_to_cart_button() {
        if (!is_product() || urna_catalog_mode_active() || urna_get_mobile_form_cart_style() === 'default' || !($product = wc_get_product()) || $product->get_type() !== 'simple') {
            return;
        }
        urna_mobile_add_add_to_cart_button_content();
    }
}

if (!function_exists('urna_mobile_add_before_variations_form')) {
    add_action('woocommerce_before_variations_form', 'urna_mobile_add_before_variations_form', 10);
    function urna_mobile_add_before_variations_form() {
        if (!is_product() || urna_catalog_mode_active() || urna_get_mobile_form_cart_style() === 'default') {
            return;
        }
        urna_mobile_add_add_to_cart_button_content();
    }
}


if (!function_exists('urna_mobile_before_grouped_product_list')) {
    add_action('woocommerce_grouped_product_list_before', 'urna_mobile_before_grouped_product_list', 10);
    function urna_mobile_before_grouped_product_list() {
        if (!is_product() || urna_catalog_mode_active() || urna_get_mobile_form_cart_style() === 'default' || !($product = wc_get_product()) || $product->get_type() !== 'grouped') {
            return;
        }
        urna_mobile_add_add_to_cart_button_content();
    }
}


if (!function_exists('urna_mobile_add_btn_after_add_to_cart_form')) {
    add_action('woocommerce_after_add_to_cart_form', 'urna_mobile_add_btn_after_add_to_cart_form', 10);
    function urna_mobile_add_btn_after_add_to_cart_form() {
        if (!is_product() || urna_catalog_mode_active() || urna_get_mobile_form_cart_style() === 'default' || !($product = wc_get_product()) || $product->get_type() === 'external') {
            return;
        }
        $class = urna_tbay_get_config('enable_buy_now', false) ? ' has-buy-now' : '';
        ?>
        <div id="mobile-close-infor-wrapper"></div>
        <div class="mobile-btn-cart-click<?php echo esc_attr($class); ?>">
            <div id="tbay-click-addtocart"><?php esc_html_e('Add to cart', 'urna'); ?></div>
            <?php if (urna_tbay_get_config('enable_buy_now', false)) : ?>
                <div id="tbay-click-buy-now"><?php esc_html_e('Buy Now', 'urna'); ?></div>
            <?php endif; ?>
        </div>
        <?php
    }
}


if (!function_exists('urna_mobile_add_before_add_to_cart_form')) {
    add_action('woocommerce_before_add_to_cart_form', 'urna_mobile_add_before_add_to_cart_form', 20);
    function urna_mobile_add_before_add_to_cart_form() {
        if (!is_product() || urna_catalog_mode_active() || urna_get_mobile_form_cart_style() === 'default' || !($product = wc_get_product()) || !$product->is_type('variable') || !($attributes = $product->get_variation_attributes())) {
            return;
        }

        $selected_attributes = $product->get_default_attributes();
        $names = array_map('wc_attribute_label', array_keys($attributes));
        $defaults = array_map(function ($key, $values) use ($selected_attributes) {
            return isset($selected_attributes[$key]) && !empty($selected_attributes[$key]) ? get_term_by('slug', $selected_attributes[$key], $key)->name : esc_html__('Choose an option', 'urna');
        }, array_keys($attributes), $attributes);
        ?>
        <div class="mobile-attribute-list">
            <div class="list-wrapper">
                <div class="name"><?php echo esc_html(implode(', ', $names)); ?></div>
                <div class="value"><?php echo esc_html(implode('/ ', $defaults)); ?></div>
            </div>
            <div id="attribute-open"><i class="icon-arrow-right icons"></i></div>
        </div>
        <?php
    }
}

/**
 * Check if popup group buttons are active
 */
if (!function_exists('urna_product_active_button_popup_groups')) {
    function urna_product_active_button_popup_groups($product_id) {
        return !empty(maybe_unserialize(urna_tbay_get_config('single_aska_question'))) ||
               !empty(maybe_unserialize(get_post_meta($product_id, '_urna_delivery_return_type', true) !== 'global' ? get_post_meta($product_id, '_urna_delivery_return', true) : urna_tbay_get_config('single_delivery_return'))) ||
               !empty(maybe_unserialize(get_post_meta($product_id, '_urna_size_guide_type', true) !== 'global' ? get_post_meta($product_id, '_urna_size_guide', true) : urna_tbay_get_config('single_size_guide')));
    }
}

/**
 * Display popup group buttons
 */
if (!function_exists('urna_product_popup_group_buttons')) {
    add_action('woocommerce_after_add_to_cart_form', 'urna_product_popup_group_buttons', 35);
    function urna_product_popup_group_buttons() {
        global $product;
        $product_id = $product->get_id();
        if (!urna_product_active_button_popup_groups($product_id)) {
            return;
        }
        $size_guide_type = urna_tbay_get_config('size_guide_product_type');
        ?>
        <ul class="tbay-button-popup-wrap">
            <?php
            if ($size_guide_type === 'all' || $product->get_type() === 'variable') {
                urna_the_size_guide($product_id);
            }
            urna_the_delivery_return($product_id);
            urna_the_aska_question($product_id);
            ?>
        </ul>
        <?php
    }
}

/**
 * Single product title
 */
if (!function_exists('urna_woocommerce_single_title')) {
    function urna_woocommerce_single_title() {
        the_title('<h2 class="product_title entry-title">', '</h2>');
    }
}

/**
 * Check if variable product is out of stock
 */
if (!function_exists('urna_is_variable_product_out_of_stock')) {
    function urna_is_variable_product_out_of_stock($product) {
        $variation_ids = $product->get_visible_children();
        $out_of_stock_count = count(array_filter($variation_ids, function ($id) {
            return !wc_get_product($id)->is_in_stock();
        }));
        return count($variation_ids) === $out_of_stock_count;
    }
}

/**
 * Dequeue scripts based on layout
 */
if (!function_exists('urna_woocommerce_dequeue_script_layout_product')) {
    add_action('wp_enqueue_scripts', 'urna_woocommerce_dequeue_script_layout_product', 10);
    function urna_woocommerce_dequeue_script_layout_product() {
        global $post;
        if (!is_product() && (empty($post->post_content) || !str_contains($post->post_content, '[product_page'))) {
            return;
        }

        $sidebar_configs = urna_tbay_get_woocommerce_layout_configs();
        $images_layout = $sidebar_configs['thumbnail'] ?? 'horizontal';
        if (in_array($images_layout, ['gallery', 'stick', 'centered'])) {
            wp_dequeue_script('flexslider');
            wp_dequeue_script('zoom');
        } elseif ($images_layout === 'carousel') {
            wp_dequeue_style('photoswipe-ui-default');
            wp_dequeue_style('photoswipe');
            wp_enqueue_script('slick');
            wp_enqueue_script('urna-slick');
        }
    }
}